@@ -1,6 +1,6 @@
 ## Domain Registry Interface, .CAT policies
 ##
-## Copyright (c) 2006,2008,2009,2011,2013 Patrick Mevzek <netdri@dotandco.com>. All rights reserved.
+## Copyright (c) 2006 Patrick Mevzek <netdri@dotandco.com>. All rights reserved.
 ##
 ## This file is part of Net::DRI
 ##
@@ -10,17 +10,17 @@
 ## (at your option) any later version.
 ##
 ## See the LICENSE file that comes with this distribution for more details.
+#
+# 
+#
 ####################################################################################################
 
 package Net::DRI::DRD::CAT;
 
 use strict;
-use warnings;
-
 use base qw/Net::DRI::DRD/;
 
-use DateTime::Duration;
-use Net::DRI::Data::Contact::CAT;
+our $VERSION=do { my @r=(q$Revision: 1.2 $=~/\d+/g); sprintf("%d".".%02d" x $#r, @r); };
 
 =pod
 
@@ -50,7 +50,7 @@ Patrick Mevzek, E<lt>netdri@dotandco.comE<gt>
 
 =head1 COPYRIGHT
 
-Copyright (c) 2006,2008,2009,2011,2013 Patrick Mevzek <netdri@dotandco.com>.
+Copyright (c) 2006 Patrick Mevzek <netdri@dotandco.com>.
 All rights reserved.
 
 This program is free software; you can redistribute it and/or modify
@@ -66,9 +66,13 @@ See the LICENSE file that comes with this distribution for more details.
 
 sub new
 {
- my $class=shift;
+ my $proto=shift;
+ my $class=ref($proto) || $proto;
+
  my $self=$class->SUPER::new(@_);
  $self->{info}->{host_as_attr}=0;
+
+ bless($self,$class);
  return $self;
 }
 
@@ -78,21 +82,45 @@ sub periods  { return map { DateTime::Duration->new(years => $_) } (1..10); }
 sub name     { return 'CAT'; }
 sub tlds     { return ('cat'); }
 sub object_types { return ('domain','contact','ns'); }
-sub profile_types { return qw/epp whois/; }
 
-sub transport_protocol_default
+sub transport_protocol_compatible
 {
- my ($self,$type)=@_;
+ my ($self,$to,$po)=@_;
+ my $pn=$po->name();
+ my $tn=$to->name();
 
- return ('Net::DRI::Transport::Socket',{remote_host=>'epp.ote.puntcat.corenic.net'},'Net::DRI::Protocol::EPP::Extensions::CAT',{}) if $type eq 'epp';
- return ('Net::DRI::Transport::Socket',{remote_host=>'whois.cat'},'Net::DRI::Protocol::Whois',{})                                  if $type eq 'whois';
+ return 1 if (($pn eq 'EPP') && ($tn eq 'socket_inet'));
  return;
 }
 
-sub set_factories
+sub transport_protocol_default
 {
- my ($self,$po)=@_;
- $po->factories('contact',sub { return Net::DRI::Data::Contact::CAT->new(@_); });
+ return ('Net::DRI::Transport::Socket','Net::DRI::Protocol::EPP::Extensions::CAT');
+}
+
+####################################################################################################
+
+sub verify_name_domain
+{
+ my ($self,$ndr,$domain)=@_;
+ $domain=$ndr unless (defined($ndr) && $ndr && (ref($ndr) eq 'Net::DRI::Registry'));
+
+ my $r=$self->SUPER::check_name($domain,1);
+ return $r if ($r);
+ return 10 unless $self->is_my_tld($domain);
+
+ return 0;
+}
+
+sub domain_operation_needs_is_mine
+{
+ my ($self,$ndr,$domain,$op)=@_;
+ ($domain,$op)=($ndr,$domain) unless (defined($ndr) && $ndr && (ref($ndr) eq 'Net::DRI::Registry'));
+
+ return unless defined($op);
+
+ return 1 if ($op=~m/^(?:renew|update|delete)$/);
+ return 0 if ($op eq 'transfer');
  return;
 }
 
