@@ -1,6 +1,6 @@
 ## Domain Registry Interface, DAS Protocol (.BE & .EU)
 ##
-## Copyright (c) 2007-2010,2013 Patrick Mevzek <netdri@dotandco.com>. All rights reserved.
+## Copyright (c) 2007 Patrick Mevzek <netdri@dotandco.com>. All rights reserved.
 ##
 ## This file is part of Net::DRI
 ##
@@ -10,18 +10,23 @@
 ## (at your option) any later version.
 ##
 ## See the LICENSE file that comes with this distribution for more details.
+#
+# 
+#
 ####################################################################################################
 
 package Net::DRI::Protocol::DAS;
 
 use strict;
-use warnings;
 
 use base qw(Net::DRI::Protocol);
 
 use Net::DRI::Util;
+use Net::DRI::Exception;
 use Net::DRI::Protocol::DAS::Message;
 
+our $VERSION=do { my @r=(q$Revision: 1.1 $=~/\d+/g); sprintf("%d".".%02d" x $#r, @r); };
+
 =pod
 
 =head1 NAME
@@ -50,7 +55,7 @@ Patrick Mevzek, E<lt>netdri@dotandco.comE<gt>
 
 =head1 COPYRIGHT
 
-Copyright (c) 2007-2010,2013 Patrick Mevzek <netdri@dotandco.com>.
+Copyright (c) 2007 Patrick Mevzek <netdri@dotandco.com>.
 All rights reserved.
 
 This program is free software; you can redistribute it and/or modify
@@ -66,31 +71,33 @@ See the LICENSE file that comes with this distribution for more details.
 
 sub new
 {
- my ($c,$ctx,$rp)=@_;
- my $drd=$ctx->{registry}->driver();
- my $self=$c->SUPER::new($ctx);
+ my $h=shift;
+ my $c=ref($h) || $h;
+
+ my ($drd,$version,$extrah)=@_;
+
+ my $self=$c->SUPER::new(); ## we are now officially a Net::DRI::Protocol object
  $self->name('DAS');
- my $version=Net::DRI::Util::check_equal($rp->{version},['1.0','2.0'],'1.0');
+ $version=Net::DRI::Util::check_equal($version,['1.0'],'1.0');
  $self->version($version);
- $self->default_parameters({ tld => (exists $rp->{no_tld} && $rp->{no_tld})? ($drd->tlds())[0] : undef });
- $self->factories('message',sub { return Net::DRI::Protocol::DAS::Message->new(@_)->version($version); });
- $self->_load($rp);
+
+ bless($self,$c); ## rebless
+
+ my @tlds=$drd->tlds();
+ Net::DRI::Exception::usererr_invalid_parameters('DAS can not be used for registry handling multiple TLDs: '.join(',',@tlds)) unless @tlds==1;
+ $self->default_parameters({ tld => $tlds[0] });
+ $self->factories({ message => sub { return Net::DRI::Protocol::DAS::Message->new(@_)->version($version); } });
+ $self->_load($extrah);
  return $self;
 }
 
 sub _load
 {
- my ($self,$rp)=@_;
- return $self->SUPER::_load('Net::DRI::Protocol::DAS::Domain');
+ my ($self,$extrah)=@_;
+ $self->SUPER::_load('Net::DRI::Protocol::DAS::Domain');
 }
 
 sub tld { return shift->{default_parameters}->{tld}; }
 
-sub transport_default
-{
- my ($self)=@_;
- return (protocol_connection => 'Net::DRI::Protocol::DAS::Connection', protocol_version => 1);
-}
-
-####################################################################################################
+############################################################################################
 1;
