@@ -1,7 +1,7 @@
 ## Domain Registry Interface, nic.at domain transactions extension
 ## Contributed by Michael Braunoeder from NIC.AT <mib@nic.at>
 ##
-## Copyright (c) 2006-2008,2013,2018 Patrick Mevzek <netdri@dotandco.com>. All rights reserved.
+## Copyright (c) 2006,2007 Patrick Mevzek <netdri@dotandco.com>. All rights reserved.
 ##
 ## This file is part of Net::DRI
 ##
@@ -11,13 +11,17 @@
 ## (at your option) any later version.
 ##
 ## See the LICENSE file that comes with this distribution for more details.
+#
+# 
+#
 ####################################################################################################
 
 package Net::DRI::Protocol::EPP::Extensions::AT::ATResult;
 
 use strict;
-use warnings;
-use feature 'state';
+
+our $VERSION=do { my @r=(q$Revision: 1.2 $=~/\d+/g); sprintf("%d".".%02d" x $#r, @r); };
+our $NS='http://www.nic.at/xsd/at-ext-result-1.0';
 
 =pod
 
@@ -47,7 +51,7 @@ Patrick Mevzek, E<lt>netdri@dotandco.comE<gt>
 
 =head1 COPYRIGHT
 
-Copyright (c) 2006-2008,2013,2018 Patrick Mevzek <netdri@dotandco.com>.
+Copyright (c) 2006,2007 Patrick Mevzek <netdri@dotandco.com>.
 All rights reserved.
 
 This program is free software; you can redistribute it and/or modify
@@ -82,14 +86,6 @@ sub register_commands
                   'contact' => \%tmp };
 }
 
-sub setup
-{
- my ($class,$po,$version)=@_;
-
- state $ns = { 'at-ext-result' => 'http://www.nic.at/xsd/at-ext-result-1.0' };
- $po->ns($ns);
- return;
-}
 
 sub condition_parse
 {
@@ -97,12 +93,12 @@ sub condition_parse
  my $mes=$po->message();
 
 
- my $condata=$mes->get_extension('at-ext-result', 'conditions');
+ my $condata=$mes->get_content('conditions',$NS,1);
  return unless $condata;
 
  my @conditions;
- my $ns = $mes->ns('at-ext-result');
- foreach my $el ($condata->getElementsByTagNameNS($ns, 'condition'))
+
+ foreach my $el ($condata->getElementsByTagNameNS($NS,'condition'))
  {
   my %con;
   my $c=$el->getFirstChild();
@@ -113,7 +109,6 @@ sub condition_parse
 
   while ($c)
   {
-   next unless ($c->nodeType() == 1); ## only for element nodes
    my $name=$c->localname() || $c->nodeName();
    next unless $name;
    if ($name=~m/^(msg|details)$/)
@@ -121,18 +116,18 @@ sub condition_parse
     $con{$1}=$c->getFirstChild()->getData();
    } elsif ($name=~m/^attributes$/)
      {
-	foreach my $attr ($c->getChildrenByTagNameNS($ns, 'attr')) {
+	foreach my $attr ($c->getChildrenByTagNameNS($NS,'attr')) {
                 my $attrname=$attr->getAttribute('name');
                 $con{"attr " .$attrname} = $attr->getFirstChild()->getData();
         }
      }
-  } continue { $c=$c->getNextSibling(); }
+   $c=$c->getNextSibling();
+  }
   push @conditions,\%con;
  }
 
  $rinfo->{domain}->{$oname}->{conditions}=\@conditions;
  $rinfo->{contact}->{$oname}->{conditions}=\@conditions;
- return;
 }
 
 ####################################################################################################
