@@ -1,7 +1,7 @@
 ## Domain Registry Interface, ENUM.AT Result Condition
 ## Contributed by Michael Braunoeder from ENUM.AT <michael.braunoeder@enum.at>
 ##
-## Copyright (c) 2006,2007,2013 Patrick Mevzek <netdri@dotandco.com>. All rights reserved.
+## Copyright (c) 2006 Patrick Mevzek <netdri@dotandco.com>. All rights reserved.
 ##
 ## This file is part of Net::DRI
 ##
@@ -11,16 +11,19 @@
 ## (at your option) any later version.
 ##
 ## See the LICENSE file that comes with this distribution for more details.
+#
+# 
+#
 ####################################################################################################
 
 package Net::DRI::Protocol::EPP::Extensions::AT::Result;
 
 use strict;
-use warnings;
 
 use Net::DRI::Util;
 use Net::DRI::Exception;
 
+our $VERSION=do { my @r=(q$Revision: 1.2 $=~/\d+/g); sprintf("%d".".%02d" x $#r, @r); };
 our $NS='http://www.enum.at/rxsd/ienum43-result-1.0';
 
 =pod
@@ -51,7 +54,7 @@ Patrick Mevzek, E<lt>netdri@dotandco.comE<gt>
 
 =head1 COPYRIGHT
 
-Copyright (c) 2006,2007,2013 Patrick Mevzek <netdri@dotandco.com>.
+Copyright (c) 2006 Patrick Mevzek <netdri@dotandco.com>.
 All rights reserved.
 
 This program is free software; you can redistribute it and/or modify
@@ -90,7 +93,7 @@ sub condition_parse
  my ($po,$otype,$oaction,$oname,$rinfo)=@_;
  my $mes=$po->message();
 
- my $condata=$mes->get_extension($NS,'conditions');
+ my $condata=$mes->get_content('conditions',$NS,1);
  return unless $condata;
 
  my @conditions;
@@ -105,19 +108,18 @@ sub condition_parse
 
   while ($c)
   {
-   next unless ($c->nodeType() == 1); ## only for element nodes
    my $name=$c->localname() || $c->nodeName();
    next unless $name;
    if ($name=~m/^(msg|details)$/)
    {
     $con{$1}=$c->getFirstChild()->getData();
    }
-  } continue { $c=$c->getNextSibling(); }
+   $c=$c->getNextSibling();
+  }
   push @conditions,\%con;
  }
 
  $rinfo->{domain}->{$oname}->{conditions}=\@conditions;
- return;
 }
 
 ####################################################################################################
