@@ -1,6 +1,6 @@
 ## Domain Registry Interface, .CAT Contact EPP extension commands
 ##
-## Copyright (c) 2006,2008,2013,2016,2019 Patrick Mevzek <netdri@dotandco.com>. All rights reserved.
+## Copyright (c) 2006 Patrick Mevzek <netdri@dotandco.com>. All rights reserved.
 ##
 ## This file is part of Net::DRI
 ##
@@ -10,12 +10,16 @@
 ## (at your option) any later version.
 ##
 ## See the LICENSE file that comes with this distribution for more details.
+#
+# 
+#
 ####################################################################################################
 
 package Net::DRI::Protocol::EPP::Extensions::CAT::Contact;
 
 use strict;
-use warnings;
+
+our $VERSION=do { my @r=(q$Revision: 1.1 $=~/\d+/g); sprintf("%d".".%02d" x $#r, @r); };
 
 =pod
 
@@ -45,7 +49,7 @@ Patrick Mevzek, E<lt>netdri@dotandco.comE<gt>
 
 =head1 COPYRIGHT
 
-Copyright (c) 2006,2008,2013,2016,2019 Patrick Mevzek <netdri@dotandco.com>.
+Copyright (c) 2006 Patrick Mevzek <netdri@dotandco.com>.
 All rights reserved.
 
 This program is free software; you can redistribute it and/or modify
@@ -73,6 +77,14 @@ sub register_commands
 
 ####################################################################################################
 
+sub build_command_extension
+{
+ my ($mes,$epp,$tag)=@_;
+
+ my @ns=@{$mes->ns()->{'puntcat_contact'}};
+ return $mes->command_extension_register($tag,sprintf('xmlns:cx="%s" xsi:schemaLocation="%s %s"',$ns[0],$ns[0],$ns[1]));
+}
+
 sub add_puntcat_extension
 {
  my ($contact)=@_;
@@ -88,25 +100,29 @@ sub add_puntcat_extension
 
 sub create
 {
- my ($epp, $contact)=@_;
+ my ($epp,$contact)=@_;
+ my $mes=$epp->message();
+ 
+ my @n=add_puntcat_extension($contact);
+ return unless @n;
 
- my @n = add_puntcat_extension($contact);
- $epp->message()->command_extension('cx', ['create', @n]) if @n;
-
- return;
+ my $eid=build_command_extension($mes,$epp,'cx:create');
+ $mes->command_extension($eid,\@n);
 }
 
 sub update
 {
- my ($epp, $domain, $todo)=@_;
+ my ($epp,$domain,$todo)=@_;
+ my $mes=$epp->message();
 
  my $newc=$todo->set('info');
  return unless $newc; ## if there already verified in Core
 
- my @n = add_puntcat_extension($newc);
- $epp->message()->command_extension('cx', ['update', ['chg', @n]]) if @n;
+ my @n=add_puntcat_extension($newc);
+ return unless @n;
 
- return;
+ my $eid=build_command_extension($mes,$epp,'cx:update');
+ $mes->command_extension($eid,['cx:chg',@n]);
 }
 
 sub info_parse
@@ -115,18 +131,17 @@ sub info_parse
  my $mes=$po->message();
  return unless $mes->is_success();
 
- my $infdata=$mes->get_extension('cx','infData');
+ my $infdata=$mes->get_content('infData',$mes->ns('puntcat_contact'),1);
  return unless $infdata;
 
  my $s=$rinfo->{contact}->{$oname}->{self};
- my $ns=$mes->ns('cx');
- my $el=$infdata->getChildrenByTagNameNS($ns,'language');
+
+ my $el=$infdata->getElementsByTagNameNS($mes->ns('puntcat_contact'),'language');
  $s->lang($el->get_node(1)->getFirstChild()->getData()) if $el;
- $el=$infdata->getChildrenByTagNameNS($ns,'maintainer');
+ $el=$infdata->getElementsByTagNameNS($mes->ns('puntcat_contact'),'maintainer');
  $s->maintainer($el->get_node(1)->getFirstChild()->getData()) if $el;
- $el=$infdata->getChildrenByTagNameNS($ns,'sponsorEmail');
+ $el=$infdata->getElementsByTagNameNS($mes->ns('puntcat_contact'),'sponsorEmail');
  $s->email_sponsor($el->get_node(1)->getFirstChild()->getData()) if $el;
- return;
 }
 
 ####################################################################################################
