@@ -1,6 +1,6 @@
 ## Domain Registry Interface, .CAT Domain EPP extension commands
 ##
-## Copyright (c) 2006-2008,2012-2014,2016,2019 Patrick Mevzek <netdri@dotandco.com>. All rights reserved.
+## Copyright (c) 2006 Patrick Mevzek <netdri@dotandco.com>. All rights reserved.
 ##
 ## This file is part of Net::DRI
 ##
@@ -10,17 +10,21 @@
 ## (at your option) any later version.
 ##
 ## See the LICENSE file that comes with this distribution for more details.
+#
+# 
+#
 ####################################################################################################
 
 package Net::DRI::Protocol::EPP::Extensions::CAT::Domain;
 
 use strict;
-use warnings;
 
 use Email::Valid;
 use Net::DRI::Util;
 use Net::DRI::Exception;
 
+our $VERSION=do { my @r=(q$Revision: 1.3 $=~/\d+/g); sprintf("%d".".%02d" x $#r, @r); };
+
 =pod
 
 =head1 NAME
@@ -49,7 +53,7 @@ Patrick Mevzek, E<lt>netdri@dotandco.comE<gt>
 
 =head1 COPYRIGHT
 
-Copyright (c) 2006-2008,2012-2014,2016,2019 Patrick Mevzek <netdri@dotandco.com>.
+Copyright (c) 2006 Patrick Mevzek <netdri@dotandco.com>.
 All rights reserved.
 
 This program is free software; you can redistribute it and/or modify
@@ -66,7 +70,7 @@ See the LICENSE file that comes with this distribution for more details.
 sub register_commands
 {
  my ($class,$version)=@_;
- my %tmp=(
+ my %tmp=( 
           create            => [ \&create, undef ],
           update            => [ \&update, undef ],
           info              => [ undef, \&info_parse ],
@@ -75,8 +79,21 @@ sub register_commands
  return { 'domain' => \%tmp };
 }
 
+sub capabilities_add
+{
+ return { 'domain_update' => { 'name_variant' => ['add','del'], 'lang' => ['set'], 'maintainer' => ['set'], 'intended_use' => ['set'] } };
+}
+
 ####################################################################################################
 
+sub build_command_extension
+{
+ my ($mes,$epp,$tag)=@_;
+ 
+ my @ns=@{$mes->ns()->{'puntcat_domain'}};
+ return $mes->command_extension_register($tag,sprintf('xmlns:dx="%s" xsi:schemaLocation="%s %s"',$ns[0],$ns[0],$ns[1]));
+}
+
 sub add_name_variant
 {
  my ($d)=@_;
@@ -84,7 +101,7 @@ sub add_name_variant
 
  foreach my $n ((ref($d) eq 'ARRAY')? @{$d} : ($d))
  {
-  Net::DRI::Exception::usererr_invalid_parameters($n.' in name_variant attribute must be an XML token between 1 & 255 chars in length') unless Net::DRI::Util::xml_is_token($n,1,255);
+  Net::DRI::Exception::usererr_invalid_parameters("$n in name_variant attribute must be an XML token between 1 & 255 chars in length") unless Net::DRI::Util::xml_is_token($n,1,255);
   push @n,['dx:nameVariant',$n];
  }
 
@@ -94,71 +111,55 @@ sub add_name_variant
 sub add_lang
 {
  my ($d)=@_;
- Net::DRI::Exception::usererr_invalid_parameters('lang attribute must be an XML language') unless (($d eq '') || Net::DRI::Util::xml_is_language($d));
+ Net::DRI::Exception::usererr_invalid_parameters("lang attribute must be an XML language") unless (($d eq '') || Net::DRI::Util::xml_is_language($d));
  return ['dx:language',$d];
 }
 
 sub add_maintainer
 {
  my ($d)=@_;
- Net::DRI::Exception::usererr_invalid_parameters('maintainer attribute must be an XML token not more than 128 chars long') unless Net::DRI::Util::xml_is_token($d,undef,128);
+ Net::DRI::Exception::usererr_invalid_parameters("maintainer attribute must be an XML token not more than 128 chars long") unless Net::DRI::Util::xml_is_token($d,undef,128);
  return ['dx:maintainer',$d];
 }
 
 sub add_intended_use
 {
  my ($d)=@_;
- Net::DRI::Exception::usererr_invalid_parameters('intended_use must be a string between 1 and 1000 chars long') unless (''.$d && (length $d <= 1000));
+ Net::DRI::Exception::usererr_invalid_parameters('intended_use must be a string between 1 and 1000 chars long') unless (''.$d && (length($d) <= 1000));
  return ['dx:intendedUse',$d];
 }
 
-sub add_disclose
-{
- my ($rd)=@_;
- Net::DRI::Exception::usererr_invalid_parameters('registrant_disclosure must be a ref hash') unless ref $rd eq 'HASH';
- Net::DRI::Exception::usererr_invalid_parameters('registrant_disclosure must have a type key') unless exists $rd->{type};
- Net::DRI::Exception::usererr_invalid_parameters('registrant_disclosure type key must have value "natural" or "legal"') unless $rd->{type}=~m/^(?:natural|legal)$/;
- if ($rd->{type} eq 'natural')
- {
-  Net::DRI::Exception::usererr_invalid_parameters('registrant_disclosure must have a disclose key when type=natural') unless exists $rd->{disclose};
-  return ['dx:disclosure',['dx:natural',{disclose => $rd->{disclose} ? 'true' : 'false' }]];
- } else
- {
-  return ['dx:disclosure',['dx:legal']];
- }
-}
-
 sub add_puntcat_extension
 {
  my ($rd)=@_;
  my @n;
- return @n unless (defined $rd && ref $rd eq 'HASH' && keys %$rd);
+ return @n unless (defined($rd) && (ref($rd) eq 'HASH') && keys(%$rd));
 
- if (exists $rd->{name_variant} && defined $rd->{name_variant})
+ if (exists($rd->{name_variant}) && defined($rd->{name_variant}))
  {
   push @n,add_name_variant($rd->{name_variant});
  }
+ 
+ push @n,add_lang($rd->{lang})             if (exists($rd->{lang}) && defined($rd->{lang}));
+ push @n,add_maintainer($rd->{maintainer}) if (exists($rd->{maintainer}) && defined($rd->{maintainer}));
 
- push @n,add_lang($rd->{lang})             if (exists $rd->{lang} && defined $rd->{lang});
- push @n,add_maintainer($rd->{maintainer}) if (exists $rd->{maintainer} && defined $rd->{maintainer});
-
- Net::DRI::Exception::usererr_insufficient_parameters('ens block is mandatory, since intendeduse are mandatory') unless (exists $rd->{ens} && defined $rd->{ens} && (ref $rd->{ens} eq 'HASH'));
+ Net::DRI::Exception::usererr_insufficient_parameters('ens block is mandatory, since intendeduse are mandatory') unless (exists($rd->{ens}) && defined($rd->{ens}) && (ref(($rd->{ens})) eq 'HASH'));
  my %ens=%{$rd->{ens}};
  my @ens;
 
- if (exists $ens{auth} && defined $ens{auth})
+ if (exists($ens{auth}) && defined($ens{auth}))
  {
-  my %auth=(ref $ens{auth} eq 'HASH')? (key => $ens{auth}->{key}, id => $ens{auth}->{id} ) : (id => $ens{auth});
-  Net::DRI::Exception::usererr_insufficient_parameters('in ens auth block, id is mandatory') unless (exists $auth{id} && defined $auth{id});
+  my %auth=(ref($ens{auth}) eq 'HASH')? (key => $ens{auth}->{key}, id => $ens{auth}->{id} ) : (id => $ens{auth});
+  Net::DRI::Exception::usererr_insufficient_parameters('in ens auth block, id is mandatory') unless (exists($auth{id}) && defined($auth{id}));
   Net::DRI::Exception::usererr_invalid_parameters('id in ens auth block must be XML token between 1 and 20 chars long') if !Net::DRI::Util::xml_is_token($auth{id},1,20);
-  Net::DRI::Exception::usererr_invalid_parameters('key in ens auth block must be XML token between 1 and 20 chars long') if (exists $auth{key} && !Net::DRI::Util::xml_is_token($auth{key},1,20));
+  Net::DRI::Exception::usererr_invalid_parameters('key in ens auth block must be XML token between 1 and 20 chars long') if (exists($auth{key}) && !Net::DRI::Util::xml_is_token($auth{key},1,20));
   push @ens,['dx:auth',\%auth];
  }
 
- if (exists $ens{sponsor} && defined $ens{sponsor})
+ if (exists($ens{sponsor}) && defined($ens{sponsor}))
  {
   my @e;
-  foreach my $e ((ref $ens{sponsor} eq 'ARRAY')? @{$ens{sponsor}} : ($ens{sponsor}))
+  foreach my $e ((ref($ens{sponsor}) eq 'ARRAY')? @{$ens{sponsor}} : ($ens{sponsor}))
   {
    Net::DRI::Exception::usererr_invalid_parameters("sponsor value $e in ens block must be a valid email address") unless (defined($e) && Net::DRI::Util::xml_is_token($e,1,undef) && Email::Valid->rfc822($e));
    push @e,['dx:sponsor',$e];
@@ -166,51 +167,53 @@ sub add_puntcat_extension
   Net::DRI::Exception::usererr_invalid_parameters('there must be either 1 or 3 sponsors') unless (@e==1 || @e==3);
   push @ens,['dx:sponsoring',@e];
  }
-
- if (exists $ens{ref_url} && defined $ens{ref_url})
+ 
+ if (exists($ens{ref_url}) && defined($ens{ref_url}))
  {
   Net::DRI::Exception::usererr_invalid_parameters('ref_url in ens auth block must be XML token between 1 and 255 chars long') unless Net::DRI::Util::xml_is_token($ens{ref_url},1,255);
   push @ens,['dx:refURL',$ens{ref_url}];
  }
 
- if (exists $ens{registration_type} && defined $ens{registration_type})
+ if (exists($ens{registration_type}) && defined($ens{registration_type}))
  {
   Net::DRI::Exception::usererr_invalid_parameters('registration_type in ens auth block must be XML token between 1 and 128 chars long') unless Net::DRI::Util::xml_is_token($ens{registration_type},1,128);
   push @ens,['dx:registrationType',$ens{registration_type}];
  }
 
- Net::DRI::Exception::usererr_insufficient_parameters('intended_use in ens auth block is mandatory') unless (exists $ens{intended_use} && defined $ens{intended_use});
+ Net::DRI::Exception::usererr_insufficient_parameters('intended_use in ens auth block is mandatory') unless (exists($ens{intended_use}) && defined($ens{intended_use}));
  push @ens,add_intended_use($ens{intended_use});
 
  push @n,['dx:ens',@ens] if @ens;
-
- push @n,add_disclose($rd->{registrant_disclosure}) if Net::DRI::Util::has_key($rd,'registrant_disclosure');
  return @n;
 }
 
 sub create
 {
- my ($epp, $domain, $rd)=@_;
+ my ($epp,$domain,$rd)=@_;
+ my $mes=$epp->message();
 
- my @n = add_puntcat_extension($rd);
- $epp->message()->command_extension('dx', ['create', @n]) if @n;
+ my @n=add_puntcat_extension($rd);
+ return unless @n;
 
- return;
+ my $eid=build_command_extension($mes,$epp,'dx:create');
+ $mes->command_extension($eid,\@n);
 }
 
 sub update
 {
  my ($epp,$domain,$todo)=@_;
+ my $mes=$epp->message();
+ 
  my (@tmp,@n);
 
  if ($todo->types('name_variant'))
  {
   Net::DRI::Exception->die(0,'protocol/EPP',11,'Only name_variant add/del available for domain') if grep { ! /^(?:add|del)$/ } $todo->types('name_variant');
-
+ 
   @tmp=add_name_variant($todo->add('name_variant'));
-  push @n,['add', @tmp] if @tmp;
+  push @n,['dx:add',@tmp] if @tmp;
   @tmp=add_name_variant($todo->del('name_variant'));
-  push @n,['rem', @tmp] if @tmp;
+  push @n,['dx:rem',@tmp] if @tmp;
  }
 
  @tmp=();
@@ -230,15 +233,13 @@ sub update
   Net::DRI::Exception->die(0,'protocol/EPP',11,'Only intended_use set available for domain') if grep { $_ ne 'set' } $todo->types('intended_use');
   push @tmp,add_intended_use($todo->set('intended_use'));
  }
- if ($todo->types('registrant_disclosure'))
- {
-  Net::DRI::Exception->die(0,'protocol/EPP',11,'Only registrant_disclosure set available for domain') if grep { $_ ne 'set' } $todo->types('registrant_disclosure');
-  push @tmp,add_disclose($todo->set('registrant_disclosure'));
- }
- push @n, ['chg', @tmp] if @tmp;
+ 
 
- $epp->message()->command_extension('dx', ['update', @n]) if @n;
- return;
+ push @n,['dx:chg',@tmp] if @tmp;
+
+ return unless @n;
+ my $eid=build_command_extension($mes,$epp,'dx:update');
+ $mes->command_extension($eid,\@n);
 }
 
 sub info_parse
@@ -247,56 +248,55 @@ sub info_parse
  my $mes=$po->message();
  return unless $mes->is_success();
 
- my $infdata=$mes->get_extension('dx','infData');
+ my $infdata=$mes->get_content('infData',$mes->ns('puntcat_domain'),1);
  return unless $infdata;
 
- my $ns=$mes->ns('dx');
- foreach my $el (Net::DRI::Util::xml_list_children($infdata))
+ my $c=$infdata->getFirstChild();
+ while($c)
  {
-  my ($name,$c)=@$el;
+  my $name=$c->localname() || $c->nodeName();
+  next unless $name;
+
   if ($name eq 'nameVariant')
   {
-   push @{$rinfo->{domain}->{$oname}->{name_variant}},$c->textContent();
+   push @{$rinfo->{domain}->{$oname}->{name_variant}},$c->getFirstChild()->getData();
   } elsif ($name eq 'language')
   {
-   $rinfo->{domain}->{$oname}->{lang}=$c->textContent();
+   $rinfo->{domain}->{$oname}->{lang}=$c->getFirstChild()->getData();
   } elsif ($name eq 'maintainer')
   {
-   $rinfo->{domain}->{$oname}->{maintainer}=$c->textContent();
+   $rinfo->{domain}->{$oname}->{maintainer}=$c->getFirstChild()->getData();
   } elsif ($name eq 'ens')
   {
    my %ens;
-   foreach my $ell (Net::DRI::Util::xml_list_children($c))
+   my $cc=$c->getFirstChild();
+   while($cc)
    {
-    my ($name2,$cc)=@$ell;
+    my $name2=$cc->localname() || $cc->nodeName();
+    next unless $name2;
     if ($name2 eq 'auth')
     {
      $ens{auth}={ id => $cc->getAttribute('id') };
     } elsif ($name2 eq 'sponsoring')
     {
-     $ens{sponsor}=[ map { $_->textContent() } $cc->getChildrenByTagNameNS($ns,'sponsor') ];
+     $ens{sponsor}=[ map { $_->getFirstChild()->getData() } $cc->getElementsByTagNameNS($mes->ns('puntcat_domain'),'sponsor') ]; 
     } elsif ($name2 eq 'refURL')
     {
-     $ens{ref_url}=$cc->textContent();
+     $ens{ref_url}=$cc->getFirstChild()->getData();
     } elsif ($name2 eq 'registrationType')
     {
-     $ens{registration_type}=$cc->textContent();
+     $ens{registration_type}=$cc->getFirstChild()->getData();
     } elsif ($name2 eq 'intendedUse')
     {
-     $ens{intended_use}=$cc->textContent();
+     $ens{intended_use}=$cc->getFirstChild()->getData();
     }
+    $cc=$cc->getNextSibling();
    }
    $rinfo->{domain}->{$oname}->{ens}=\%ens;
-  } elsif ($name eq 'disclosure')
-  {
-   my @d=@{(Net::DRI::Util::xml_list_children($c))[0]};
-   my %e;
-   $e{type}=$d[0]; ## natural or legal
-   $e{disclose}=Net::DRI::Util::xml_parse_boolean($d[1]->getAttribute('disclose')) if ($e{type} eq 'natural');
-   $rinfo->{domain}->{$oname}->{registrant_disclosure}=\%e;
   }
+
+  $c=$c->getNextSibling();
  }
- return;
 }
 
 ####################################################################################################
