@@ -1,6 +1,6 @@
 ## Domain Registry Interface, EPP Message for DNSBE
 ##
-## Copyright (c) 2006,2008-2010,2013 Patrick Mevzek <netdri@dotandco.com>. All rights reserved.
+## Copyright (c) 2006 Patrick Mevzek <netdri@dotandco.com>. All rights reserved.
 ##
 ## This file is part of Net::DRI
 ##
@@ -10,12 +10,18 @@
 ## (at your option) any later version.
 ##
 ## See the LICENSE file that comes with this distribution for more details.
-####################################################################################################
+#
+# 
+#
+#########################################################################################
 
 package Net::DRI::Protocol::EPP::Extensions::DNSBE::Message;
 
 use strict;
-use warnings;
+
+use base qw/Net::DRI::Protocol::EPP::Message/;
+
+our $VERSION=do { my @r=(q$Revision: 1.1 $=~/\d+/g); sprintf("%d".".%02d" x $#r, @r); };
 
 =pod
 
@@ -45,7 +51,7 @@ Patrick Mevzek, E<lt>netdri@dotandco.comE<gt>
 
 =head1 COPYRIGHT
 
-Copyright (c) 2006,2008-2010,2013 Patrick Mevzek <netdri@dotandco.com>.
+Copyright (c) 2006 Patrick Mevzek <netdri@dotandco.com>.
 All rights reserved.
 
 This program is free software; you can redistribute it and/or modify
@@ -59,27 +65,19 @@ See the LICENSE file that comes with this distribution for more details.
 
 ####################################################################################################
 
-sub register_commands
-{
- my ($class,$version)=@_;
- return { 'message' => { 'result' => [ undef, \&parse ] } };
-}
-
 sub parse
 {
- my ($po,$otype,$oaction,$oname,$rinfo)=@_;
- my $mes=$po->message();
+ my $self=shift;
+ $self->SUPER::parse(@_);
 
  ## Parse dnsbe:ext
- my $result=$mes->get_extension('dnsbe','result');
+ my $result=$self->get_content('result',$self->ns('dnsbe'),1);
  return unless $result;
 
- ## We add it to the latest status extra_info seen.
- foreach my $el ($result->getChildrenByTagNameNS($mes->ns('dnsbe'),'msg'))
+ foreach my $el ($result->getElementsByTagNameNS($self->ns('dnsbe'),'msg'))
  {
-  $mes->add_to_extra_info({from => 'dnsbe', type => 'text', message => $el->textContent()});
+  push @{$self->{result_extra_info}},$el->getFirstChild()->getData();
  }
- return;
 }
 
 ####################################################################################################
