@@ -1,6 +1,6 @@
 ## Domain Registry Interface, .LU Contact EPP extension commands
 ##
-## Copyright (c) 2007,2008,2013,2016,2019 Patrick Mevzek <netdri@dotandco.com>. All rights reserved.
+## Copyright (c) 2007 Patrick Mevzek <netdri@dotandco.com>. All rights reserved.
 ##
 ## This file is part of Net::DRI
 ##
@@ -10,15 +10,19 @@
 ## (at your option) any later version.
 ##
 ## See the LICENSE file that comes with this distribution for more details.
+#
+# 
+#
 ####################################################################################################
 
 package Net::DRI::Protocol::EPP::Extensions::LU::Contact;
 
 use strict;
-use warnings;
 
 use Net::DRI::Util;
 
+our $VERSION=do { my @r=(q$Revision: 1.1 $=~/\d+/g); sprintf("%d".".%02d" x $#r, @r); };
+
 =pod
 
 =head1 NAME
@@ -47,7 +51,7 @@ Patrick Mevzek, E<lt>netdri@dotandco.comE<gt>
 
 =head1 COPYRIGHT
 
-Copyright (c) 2007,2008,2013,2016,2019 Patrick Mevzek <netdri@dotandco.com>.
+Copyright (c) 2007 Patrick Mevzek <netdri@dotandco.com>.
 All rights reserved.
 
 This program is free software; you can redistribute it and/or modify
@@ -73,6 +77,14 @@ sub register_commands
  return { 'contact' => \%tmp };
 }
 
+sub build_command_extension
+{
+ my ($mes,$epp,$tag)=@_;
+
+ my @ns=@{$mes->ns->{dnslu}};
+ return $mes->command_extension_register($tag,sprintf('xmlns:dnslu="%s" xsi:schemaLocation="%s %s"',$ns[0],$ns[0],$ns[1]));
+}
+
 ####################################################################################################
 
 sub info_parse
@@ -81,36 +93,31 @@ sub info_parse
  my $mes=$po->message();
  return unless $mes->is_success();
 
- my $infdata=$mes->get_extension('dnslu','ext');
+ my $infdata=$mes->get_content('infData',$mes->ns('dnslu'),1);
  return unless $infdata;
- my $ns=$mes->ns('dnslu');
- $infdata=$infdata->getChildrenByTagNameNS($ns,'resData');
- return unless $infdata->size();
- $infdata=$infdata->shift()->getChildrenByTagNameNS($ns,'infData');
- return unless $infdata->size();
- $infdata=$infdata->shift()->getChildrenByTagNameNS($ns,'contact');
- return unless $infdata->size();
- $infdata=$infdata->shift();
+
+ my @c=$infdata->getElementsByTagNameNS($mes->ns('dnslu'),'contact');
+ return unless @c;
  
  my $co=$rinfo->{contact}->{$oname}->{self};
 
- my $t=$infdata->getChildrenByTagNameNS($ns,'type');
- $co->type($t->shift->getFirstChild()->getData()) if $t->size();
+ my $t=($c[0]->getElementsByTagNameNS($mes->ns('dnslu'),'type'))[0];
+ $co->type($t->getFirstChild()->getData()) if $t;
 
- my $c=$infdata->getChildrenByTagNameNS($ns,'disclose');
- if ($c->size())
+ my $c=($infdata->getElementsByTagNameNS($mes->ns('dnslu'),'disclose'))[0];
+ if ($c)
  {
-  $c=$c->shift()->getFirstChild();
+  $c=$c->getFirstChild();
   $co->disclose({}) unless defined($co->disclose()); 
   while($c)
   {
-   next unless ($c->nodeType() == 1); ## only for element nodes
    my $name=$c->localname() || $c->nodeName();
    next unless $name;
+ 
    $co->disclose()->{$name.'_loc'}=$c->getAttribute('flag');
-  } continue { $c=$c->getNextSibling(); }
+   $c=$c->getNextSibling();
+  }
  }
- return;
 }
 
 sub build_disclose
@@ -133,6 +140,7 @@ sub build_disclose
 sub create
 {
  my ($epp,$contact)=@_;
+ my $mes=$epp->message();
 
  ## validate() has been called, we are sure that type exists
  my @n;
@@ -140,21 +148,22 @@ sub create
  my $rd=build_disclose($contact->disclose(),$contact->type());
  push @n,['dnslu:disclose',@$rd] if $rd;
 
- $epp->message()->command_extension('dnslu', ['ext', ['create', ['contact', @n]]]);
- return;
+ my $eid=build_command_extension($mes,$epp,'dnslu:ext');
+ $mes->command_extension($eid,['dnslu:create',['dnslu:contact',@n]]);
 }
 
 sub update
 {
  my ($epp,$domain,$todo)=@_;
+ my $mes=$epp->message();
 
  my @n;
  push @n,['dnslu:add',['dnslu:disclose',@{build_disclose($todo->add('disclose'),'contact')}]] if $todo->add('disclose');
  push @n,['dnslu:rem',['dnslu:disclose',@{build_disclose($todo->del('disclose'),'contact')}]] if $todo->del('disclose');
  return unless @n;
 
- $epp->message()->command_extension('dnslu', ['ext', ['update', ['contact', @n]]]);
- return;
+ my $eid=build_command_extension($mes,$epp,'dnslu:ext');
+ $mes->command_extension($eid,['dnslu:update',['dnslu:contact',@n]]);
 }
 
 ####################################################################################################
