@@ -1,6 +1,6 @@
 ## Domain Registry Interface, .LU Domain EPP extension commands
 ##
-## Copyright (c) 2007,2008,2010,2013,2016,2019 Patrick Mevzek <netdri@dotandco.com>. All rights reserved.
+## Copyright (c) 2007 Patrick Mevzek <netdri@dotandco.com>. All rights reserved.
 ##
 ## This file is part of Net::DRI
 ##
@@ -10,18 +10,22 @@
 ## (at your option) any later version.
 ##
 ## See the LICENSE file that comes with this distribution for more details.
+#
+# 
+#
 ####################################################################################################
 
 package Net::DRI::Protocol::EPP::Extensions::LU::Domain;
 
 use strict;
-use warnings;
 
 use Net::DRI::Exception;
 use Net::DRI::Util;
 
 use DateTime::Format::ISO8601;
 
+our $VERSION=do { my @r=(q$Revision: 1.1 $=~/\d+/g); sprintf("%d".".%02d" x $#r, @r); };
+
 =pod
 
 =head1 NAME
@@ -50,7 +54,7 @@ Patrick Mevzek, E<lt>netdri@dotandco.comE<gt>
 
 =head1 COPYRIGHT
 
-Copyright (c) 2007,2008,2010,2013,2016,2019 Patrick Mevzek <netdri@dotandco.com>.
+Copyright (c) 2007 Patrick Mevzek <netdri@dotandco.com>.
 All rights reserved.
 
 This program is free software; you can redistribute it and/or modify
@@ -89,6 +93,14 @@ sub register_commands
  return { 'domain' => \%tmp };
 }
 
+sub build_command_extension
+{
+ my ($mes,$epp,$tag)=@_;
+
+ my @ns=@{$mes->ns->{dnslu}};
+ return $mes->command_extension_register($tag,sprintf('xmlns:dnslu="%s" xsi:schemaLocation="%s %s"',$ns[0],$ns[0],$ns[1]));
+}
+
 ####################################################################################################
 
 sub info_parse
@@ -97,21 +109,15 @@ sub info_parse
  my $mes=$po->message();
  return unless $mes->is_success();
 
- my $infdata=$mes->get_extension('dnslu','ext');
+ my $infdata=$mes->get_content('infData',$mes->ns('dnslu'),1);
  return unless $infdata;
- my $ns=$mes->ns('dnslu');
- $infdata=$infdata->getChildrenByTagNameNS($ns,'resData');
- return unless $infdata->size();
- $infdata=$infdata->shift()->getChildrenByTagNameNS($ns,'infData');
- return unless $infdata->size();
- $infdata=$infdata->shift()->getChildrenByTagNameNS($ns,'domain');
- return unless $infdata->size();
 
- my $pd=DateTime::Format::ISO8601->new();
- my $c=$infdata->shift()->getFirstChild();
+ my @c=$infdata->getElementsByTagNameNS($mes->ns('dnslu'),'domain');
+ return unless @c;
+
+ my $c=$c[0]->getFirstChild();
  while($c)
  {
-  next unless ($c->nodeType() == 1); ## only for element nodes
   my $name=$c->localname() || $c->nodeName();
   next unless $name;
 
@@ -126,17 +132,17 @@ sub info_parse
    $rinfo->{domain}->{$oname}->{$name}=$c->getFirstChild()->getData();  
   } elsif ($name=~m/^(crReqDate|delReqDate|delDate)$/)
   {
-   $rinfo->{domain}->{$oname}->{$name}=$pd->parse_datetime($c->getFirstChild()->getData());
+   $rinfo->{domain}->{$oname}->{$name}=DateTime::Format::ISO8601->new()->parse_datetime($c->getFirstChild()->getData());
   }
 
- } continue { $c=$c->getNextSibling(); }
- return;
+  $c=$c->getNextSibling();
+ }
 }
 
 sub verify_contacts
 {
  my $rd=shift;
- Net::DRI::Exception::usererr_invalid_parameters('.LU needs contact for domain_create/domain_transfer/domain_trade') unless Net::DRI::Util::has_contact($rd);
+ Net::DRI::Exception::usererr_invalid_parameters('.LU needs contact for domain_create/domain_transfer/domain_trade') unless (defined($rd) && (ref($rd) eq 'HASH') && exists($rd->{contact}) && UNIVERSAL::isa($rd->{contact},'Net::DRI::Data::ContactSet'));
  my @t=$rd->{contact}->types();
  Net::DRI::Exception::usererr_invalid_parameters('.LU needs registrant, admin and tech contacts only') unless ($t[0] eq 'admin' && $t[1] eq 'registrant' && $t[2] eq 'tech');
  foreach my $t (qw/registrant admin tech/)
@@ -144,27 +150,28 @@ sub verify_contacts
   my @t=$rd->{contact}->get($t);
   Net::DRI::Exception::usererr_invalid_parameters('.LU needs only one contact of type '.$t) unless @t==1;
  }
- return;
 }
 
 sub create
 {
  my ($epp,$domain,$rd)=@_;
+ my $mes=$epp->message();
 
  verify_contacts($rd);
 
  ## idn is not handled
 
- return unless Net::DRI::Util::has_key($rd,'status');
- my @n=map { ['dnslu:status',{ 's' => $_ }] } (Net::DRI::Util::isa_statuslist($rd->{status})? $rd->{status}->list_status() : @{$rd->{status}});
+ return unless (exists($rd->{status}) && ref($rd->{status}));
+ my @n=map { ['dnslu:status',{ s => $_ }] } (UNIVERSAL::isa($rd->{status},'Net::DRI::Data::StatusList')? $rd->{status}->list_status() : @{$rd->{status}});
 
- $epp->message()->command_extension('dnslu', ['ext', ['create', ['domain', @n]]]);
- return;
+ my $eid=build_command_extension($mes,$epp,'dnslu:ext');
+ $mes->command_extension($eid,['dnslu:create',['dnslu:domain',@n]]);
 }
 
 sub update
 {
  my ($epp,$domain,$todo)=@_;
+ my $mes=$epp->message();
 
  my @n;
  my $sadd=$todo->add('status');
@@ -176,15 +183,16 @@ sub update
  push @n,['dnslu:rem',@del] if @del;
  return unless @n;
 
- $epp->message()->command_extension('dnslu', ['ext', ['update', ['domain', @n]]]);
- return;
+ my $eid=build_command_extension($mes,$epp,'dnslu:ext');
+ $mes->command_extension($eid,['dnslu:update',['dnslu:domain',@n]]);
 }
 
-sub delete ## no critic (Subroutines::ProhibitBuiltinHomonyms)
+sub delete
 {
  my ($epp,$domain,$rd)=@_;
+ my $mes=$epp->message();
 
- return unless (defined($rd) && ref($rd) && exists($rd->{delDate}) && ($rd->{delDate}=~m/^(?:immediate|cancel)$/ || Net::DRI::Util::is_class($rd->{delDate},'DateTime')));
+ return unless (defined($rd) && ref($rd) && exists($rd->{delDate}) && ($rd->{delDate}=~m/^(?:immediate|cancel)$/ || UNIVERSAL::isa($rd->{delDate},'DateTime')));
 
  my @n;
  if ($rd->{delDate}=~m/^(?:immediate|cancel)$/)
@@ -196,15 +204,15 @@ sub delete ## no critic (Subroutines::ProhibitBuiltinHomonyms)
   push @n,['dnslu:delDate',$rd->{delDate}->set_time_zone('UTC')->strftime('%Y-%m-%dT%TZ')];
  }
 
- $epp->message()->command_extension('dnslu', ['ext', ['delete', ['domain', @n]]]);
- return;
+ my $eid=build_command_extension($mes,$epp,'dnslu:ext');
+ $mes->command_extension($eid,['dnslu:delete',['dnslu:domain',@n]]);
 }
 
 sub build_command
 {
  my ($domain)=@_;
 
- Net::DRI::Exception->die(1,'protocol/EPP',2,'Domain name needed') unless (defined($domain) && $domain && !ref($domain));
+ Net::DRI::Exception->die(1,'protocol/EPP',2,'Domain name needed') unless defined($domain) && $domain;
  Net::DRI::Exception->die(1,'protocol/EPP',10,'Invalid domain name: '.$domain) unless Net::DRI::Util::is_hostname($domain);
  Net::DRI::Exception->die(1,'protocol/EPP',10,'Domain name not in .LU: '.$domain) unless $domain=~m/\.LU$/i;
 
@@ -214,9 +222,11 @@ sub build_command
 sub restore
 {
  my ($epp,$domain,$rd)=@_;
+ my $mes=$epp->message();
 
- $epp->message()->command_extension('dnslu', ['ext', ['command', ['restore', ['domain', build_command($domain)]]]]);
- return;
+ $mes->command(['nocommand']);
+ my $eid=build_command_extension($mes,$epp,'dnslu:ext');
+ $mes->command_extension($eid,['dnslu:command',['dnslu:restore',['dnslu:domain',build_command($domain)]]]);
 }
 
 sub build_transfer_trade_restore
@@ -226,12 +236,12 @@ sub build_transfer_trade_restore
 
  verify_contacts($rd);
  
- push @n,['dnslu:ns',map { ['dnslu:hostObj',$_] } $rd->{ns}->get_names() ] if Net::DRI::Util::has_ns($rd);
+ push @n,['dnslu:ns',map { ['dnslu:hostObj',$_] } $rd->{ns}->get_names() ] if (exists($rd->{ns}) && $rd->{ns} && UNIVERSAL::isa($rd->{ns},'Net::DRI::Data::Hosts') && !$rd->{ns}->is_empty());
  my $cs=$rd->{contact};
  push @n,['dnslu:registrant',$cs->get('registrant')->srid()];
  push @n,['dnslu:contact',{type => 'admin'},$cs->get('admin')->srid()];
  push @n,['dnslu:contact',{type => 'tech'},$cs->get('tech')->srid()];
- push @n,map { ['dnslu:status',{ 's' => $_ }] } (Net::DRI::Util::isa_statuslist($rd->{status})? $rd->{status}->list_status() : @{$rd->{status}}) if Net::DRI::Util::has_key($rd,'status');
+ push @n,map { ['dnslu:status',{ s => $_ }] } (UNIVERSAL::isa($rd->{status},'Net::DRI::Data::StatusList')? $rd->{status}->list_status() : @{$rd->{status}}) if (exists($rd->{status}) && defined($rd->{status}));
  ## IDN not used
  push @n,['dnslu:trDate',$rd->{trDate}->set_time_zone('UTC')->strftime('%Y-%m-%d')] if (exists($rd->{trDate}) && defined($rd->{trDate}) && Net::DRI::Util::check_isa($rd->{trDate},'DateTime'));
  return @n;
@@ -240,9 +250,10 @@ sub build_transfer_trade_restore
 sub transfer_request
 {
  my ($epp,$domain,$rd)=@_;
+ my $mes=$epp->message();
 
- $epp->message()->command_extension('dnslu', ['ext', ['transfer', ['domain', build_transfer_trade_restore($rd)]]]);
- return;
+ my $eid=build_command_extension($mes,$epp,'dnslu:ext');
+ $mes->command_extension($eid,['dnslu:transfer',['dnslu:domain',build_transfer_trade_restore($rd)]]);
 }
 
 sub transfer_parse ## for request & query
@@ -252,7 +263,6 @@ sub transfer_parse ## for request & query
  return unless $mes->is_success();
 
  parse_transfer_trade_restore($po,$otype,$oaction,$oname,$rinfo,'trnData');
- return;
 }
 
 sub parse_transfer_trade_restore
@@ -260,21 +270,15 @@ sub parse_transfer_trade_restore
  my ($po,$otype,$oaction,$oname,$rinfo,$s)=@_;
  my $mes=$po->message();
 
- my $infdata=$mes->get_extension('dnslu','ext');
+ my $infdata=$mes->get_content($s,$mes->ns('dnslu'),1);
  return unless $infdata;
- my $ns=$mes->ns('dnslu');
- $infdata=$infdata->getChildrenByTagNameNS($ns,'resData');
- return unless $infdata->size();
- $infdata=$infdata->shift()->getChildrenByTagNameNS($ns,$s);
- return unless $infdata->size();
- $infdata=$infdata->shift()->getChildrenByTagNameNS($ns,'domain');
- return unless $infdata->size();
 
- my $pd=DateTime::Format::ISO8601->new();
- my $c=$infdata->shift->getFirstChild();
+ my @c=$infdata->getElementsByTagNameNS($mes->ns('dnslu'),'domain');
+ return unless @c;
+
+ my $c=$c[0]->getFirstChild();
  while($c)
  {
-  next unless ($c->nodeType() == 1); ## only for element nodes
   my $name=$c->localname() || $c->nodeName();
   next unless $name;
 
@@ -286,18 +290,20 @@ sub parse_transfer_trade_restore
    $rinfo->{domain}->{$oname}->{$name}=$c->getFirstChild()->getData();
   } elsif ($name=~m/^(reDate|acDate|trDate)$/)
   {
-   $rinfo->{domain}->{$oname}->{$name}=$pd->parse_datetime($c->getFirstChild()->getData());
+   $rinfo->{domain}->{$oname}->{$name}=DateTime::Format::ISO8601->new()->parse_datetime($c->getFirstChild()->getData());
   }
- } continue { $c=$c->getNextSibling(); }
- return;
+  $c=$c->getNextSibling();
+ }
 }
 
 sub trade_request
 {
  my ($epp,$domain,$rd)=@_;
+ my $mes=$epp->message();
 
- $epp->message()->command_extension('dnslu', ['ext', ['command', ['trade', {op=>'request'}, ['domain', build_command($domain), build_transfer_trade_restore($rd)]]]]);
- return;
+ $mes->command(['nocommand']);
+ my $eid=build_command_extension($mes,$epp,'dnslu:ext');
+ $mes->command_extension($eid,['dnslu:command',['dnslu:trade',{op=>'request'},['dnslu:domain',build_command($domain),build_transfer_trade_restore($rd)]]]);
 }
 
 sub trade_parse
@@ -307,31 +313,36 @@ sub trade_parse
  return unless $mes->is_success();
 
  parse_transfer_trade_restore($po,$otype,$oaction,$oname,$rinfo,'traData');
- return;
 }
 
 sub trade_query
 {
  my ($epp,$domain,$rd)=@_;
+ my $mes=$epp->message();
 
- $epp->message()->command_extension('dnslu', ['ext', ['command', ['trade', {op=>'query'}, ['domain', build_command($domain)]]]]);
- return;
+ $mes->command(['nocommand']);
+ my $eid=build_command_extension($mes,$epp,'dnslu:ext');
+ $mes->command_extension($eid,['dnslu:command',['dnslu:trade',{op=>'query'},['dnslu:domain',build_command($domain)]]]);
 }
 
 sub trade_cancel
 {
  my ($epp,$domain,$rd)=@_;
+ my $mes=$epp->message();
 
- $epp->message()->command_extension('dnslu', ['ext', ['command', ['trade', {op=>'cancel'}, ['domain', build_command($domain)]]]]);
- return;
+ $mes->command(['nocommand']);
+ my $eid=build_command_extension($mes,$epp,'dnslu:ext');
+ $mes->command_extension($eid,['dnslu:command',['dnslu:trade',{op=>'cancel'},['dnslu:domain',build_command($domain)]]]);
 }
 
 sub transfer_trade_request
 {
  my ($epp,$domain,$rd)=@_;
+ my $mes=$epp->message();
 
- $epp->message()->command_extension('dnslu', ['ext', ['command', ['transferTrade', {op=>'request'}, ['domain', build_command($domain), build_transfer_trade_restore($rd)]]]]);
- return;
+ $mes->command(['nocommand']);
+ my $eid=build_command_extension($mes,$epp,'dnslu:ext');
+ $mes->command_extension($eid,['dnslu:command',['dnslu:transferTrade',{op=>'request'},['dnslu:domain',build_command($domain),build_transfer_trade_restore($rd)]]]);
 }
 
 sub transfer_trade_parse
@@ -341,31 +352,36 @@ sub transfer_trade_parse
  return unless $mes->is_success();
 
  parse_transfer_trade_restore($po,$otype,$oaction,$oname,$rinfo,'trnTraData');
- return;
 }
 
 sub transfer_trade_query
 {
  my ($epp,$domain,$rd)=@_;
+ my $mes=$epp->message();
 
- $epp->message()->command_extension('dnslu', ['ext', ['command', ['transferTrade', {op=>'query'}, ['domain', build_command($domain)]]]]);
- return;
+ $mes->command(['nocommand']);
+ my $eid=build_command_extension($mes,$epp,'dnslu:ext');
+ $mes->command_extension($eid,['dnslu:command',['dnslu:transferTrade',{op=>'query'},['dnslu:domain',build_command($domain)]]]);
 }
 
 sub transfer_trade_cancel
 {
  my ($epp,$domain,$rd)=@_;
+ my $mes=$epp->message();
 
- $epp->message()->command_extension('dnslu', ['ext', ['command', ['transferTrade', {op=>'cancel'}, ['domain', build_command($domain)]]]]);
- return;
+ $mes->command(['nocommand']);
+ my $eid=build_command_extension($mes,$epp,'dnslu:ext');
+ $mes->command_extension($eid,['dnslu:command',['dnslu:transferTrade',{op=>'cancel'},['dnslu:domain',build_command($domain)]]]);
 }
 
 sub transfer_restore_request
 {
  my ($epp,$domain,$rd)=@_;
+ my $mes=$epp->message();
 
- $epp->message()->command_extension('dnslu', ['ext', ['command', ['transferRestore', {op=>'request'}, ['domain', build_command($domain), build_transfer_trade_restore($rd)]]]]);
- return;
+ $mes->command(['nocommand']);
+ my $eid=build_command_extension($mes,$epp,'dnslu:ext');
+ $mes->command_extension($eid,['dnslu:command',['dnslu:transferRestore',{op=>'request'},['dnslu:domain',build_command($domain),build_transfer_trade_restore($rd)]]]);
 }
 
 sub transfer_restore_parse
@@ -375,23 +391,26 @@ sub transfer_restore_parse
  return unless $mes->is_success();
 
  parse_transfer_trade_restore($po,$otype,$oaction,$oname,$rinfo,'trnResData');
- return;
 }
 
 sub transfer_restore_query
 {
  my ($epp,$domain,$rd)=@_;
+ my $mes=$epp->message();
 
- $epp->message()->command_extension('dnslu', ['ext', ['command', ['transferRestore', {op=>'query'}, ['domain', build_command($domain)]]]]);
- return;
+ $mes->command(['nocommand']);
+ my $eid=build_command_extension($mes,$epp,'dnslu:ext');
+ $mes->command_extension($eid,['dnslu:command',['dnslu:transferRestore',{op=>'query'},['dnslu:domain',build_command($domain)]]]);
 }
 
 sub transfer_restore_cancel
 {
  my ($epp,$domain,$rd)=@_;
+ my $mes=$epp->message();
 
- $epp->message()->command_extension('dnslu', ['ext', ['command', ['transferRestore', {op=>'cancel'}, ['domain', build_command($domain)]]]]);
- return;
+ $mes->command(['nocommand']);
+ my $eid=build_command_extension($mes,$epp,'dnslu:ext');
+ $mes->command_extension($eid,['dnslu:command',['dnslu:transferRestore',{op=>'cancel'},['dnslu:domain',build_command($domain)]]]);
 }
 
 ####################################################################################################
