@@ -1,6 +1,6 @@
 ## Domain Registry Interface, EPP DNS-LU Poll extensions 
 ##
-## Copyright (c) 2007,2008,2013 Patrick Mevzek <netdri@dotandco.com>. All rights reserved.
+## Copyright (c) 2007 Patrick Mevzek <netdri@dotandco.com>. All rights reserved.
 ##
 ## This file is part of Net::DRI
 ##
@@ -10,17 +10,21 @@
 ## (at your option) any later version.
 ##
 ## See the LICENSE file that comes with this distribution for more details.
+#
+# 
+#
 ####################################################################################################
 
 package Net::DRI::Protocol::EPP::Extensions::LU::Poll;
 
 use strict;
-use warnings;
 
 use Net::DRI::Util;
 
 use DateTime::Format::ISO8601;
 
+our $VERSION=do { my @r=(q$Revision: 1.1 $=~/\d+/g); sprintf("%d".".%02d" x $#r, @r); };
+
 =pod
 
 =head1 NAME
@@ -49,7 +53,7 @@ Patrick Mevzek, E<lt>netdri@dotandco.comE<gt>
 
 =head1 COPYRIGHT
 
-Copyright (c) 2007,2008,2013 Patrick Mevzek <netdri@dotandco.com>.
+Copyright (c) 2007 Patrick Mevzek <netdri@dotandco.com>.
 All rights reserved.
 
 This program is free software; you can redistribute it and/or modify
@@ -83,15 +87,12 @@ sub parse
  my $infdata=$mes->node_msg();
  return unless $infdata;
 
- my $pollmsg=$infdata->getFirstChild();
  my %w=(action => 'dnslu_notification', type => $infdata->getAttribute('type')); ## list of types p.36
- $w{type}=$pollmsg->getAttribute('type') if (!defined($w{type}) && $pollmsg->localname() eq 'pollmsg'); 
-
  my (%ns,%e);
- my $c=$pollmsg->getFirstChild();
+
+ my $c=$infdata->getFirstChild()->getFirstChild();
  while ($c)
  {
-  next unless ($c->nodeType() == 1); ## only for element nodes
   my $name=$c->localname() || $c->nodeName();
   next unless $name;
 
@@ -109,12 +110,12 @@ sub parse
    $e{$c->getAttribute('name')}=$c->getFirstChild()->getData();
   }
 
- } continue { $c=$c->getNextSibling(); }
+  $c=$c->getNextSibling();
+ }
  $w{ns}=\%ns if %ns;
  $w{extra}=\%e if %e;
 
  $rinfo->{session}->{notification}=\%w;
- return;
 }
 
 ####################################################################################################
