@@ -1,6 +1,6 @@
 ## Domain Registry Interface, .PL Contact EPP extension commands
 ##
-## Copyright (c) 2006,2008,2011,2013,2016,2019 Patrick Mevzek <netdri@dotandco.com>. All rights reserved.
+## Copyright (c) 2006 Patrick Mevzek <netdri@dotandco.com>. All rights reserved.
 ##
 ## This file is part of Net::DRI
 ##
@@ -10,15 +10,16 @@
 ## (at your option) any later version.
 ##
 ## See the LICENSE file that comes with this distribution for more details.
+#
+# 
+#
 #########################################################################################
 
 package Net::DRI::Protocol::EPP::Extensions::PL::Contact;
 
 use strict;
-use warnings;
-use feature 'state';
 
-use Net::DRI::Util;
+our $VERSION=do { my @r=(q$Revision: 1.1 $=~/\d+/g); sprintf("%d".".%02d" x $#r, @r); };
 
 =pod
 
@@ -48,7 +49,7 @@ Patrick Mevzek, E<lt>netdri@dotandco.comE<gt>
 
 =head1 COPYRIGHT
 
-Copyright (c) 2006,2008,2011,2013,2016,2019 Patrick Mevzek <netdri@dotandco.com>.
+Copyright (c) 2006 Patrick Mevzek <netdri@dotandco.com>.
 All rights reserved.
 
 This program is free software; you can redistribute it and/or modify
@@ -65,42 +66,50 @@ See the LICENSE file that comes with this distribution for more details.
 sub register_commands
 {
  my ($class,$version)=@_;
- state $cmds = { 'contact' => { create => [ \&create, undef ],
-                                info   => [ \&info, \&info_parse ],
-                                update => [ \&update, undef ],
-                              }
-               };
+ my %tmp=( 
+          create => [ \&create, undef ],
+          info   => [ \&info, undef ],
+          update => [ \&update, undef ],
+         );
 
- return $cmds;
+ return { 'contact' => \%tmp };
 }
 
 ####################################################################################################
 
+sub build_command_extension
+{
+ my ($mes,$epp,$tag)=@_;
+
+ my @ns=@{$mes->ns->{pl_contact}};
+ return $mes->command_extension_register($tag,sprintf('xmlns:extcon="%s" xsi:schemaLocation="%s %s"',$ns[0],$ns[0],$ns[1]));
+}
+
 sub add_individual_and_consent
 {
  my ($epp,$contact,$op)=@_;
+ my $mes=$epp->message();
 
  ## validate() has already been called
  my $ind=$contact->individual();
  my $cfp=$contact->consent_for_publishing();
 
  return unless (defined($ind) || defined($cfp));
-
+ my $eid=build_command_extension($mes,$epp,'extcon:'.$op);
  my @e;
  push @e,['extcon:individual',$ind]           if defined($ind);
  push @e,['extcon:consentForPublishing',$cfp] if defined($cfp);
 
- $epp->message()->command_extension('extcon', [$op, @e]);
- return;
+ $mes->command_extension($eid,\@e);
 }
 
-sub create
+sub create 
 {
  my ($epp,$contact)=@_;
- return add_individual_and_consent($epp,$contact,'create');
+ return add_individual_and_consent($epp,$contact,'create'); 
 }
 
-sub update
+sub update 
 {
  my ($epp,$contact,$todo)=@_;
  my $newc=$todo->set('info');
@@ -111,41 +120,12 @@ sub update
 sub info
 {
  my ($epp,$contact,$ep)=@_;
+ my $mes=$epp->message();
 
- return unless (Net::DRI::Util::has_auth($ep) && exists $ep->{auth}->{pw});
+ return unless (defined($ep) && (ref($ep) eq 'HASH') && exists($ep->{auth}) && (ref($ep->{auth}) eq 'HASH') && exists($ep->{auth}->{pw}));
 
- my %roid;
- if (Net::DRI::Util::has_key($ep->{auth},'roid'))
- {
-  %roid = (roid => $ep->{auth}->{roid});
- }
- $epp->message()->command_extension('extcon', ['info', ['authInfo', ['pw', $ep->{auth}->{pw}, \%roid]]]);
- return;
-}
-
-sub info_parse
-{
- my ($po,$otype,$oaction,$oname,$rinfo)=@_;
- my $mes=$po->message();
- return unless $mes->is_success();
-
- my $infdata=$mes->get_extension('extcon','infData');
- return unless defined $infdata;
-
- my $contact=$rinfo->{contact}->{$oname}->{self};
-
- foreach my $el (Net::DRI::Util::xml_list_children($infdata))
- {
-  my ($name,$c)=@$el;
-  if ($name eq 'individual')
-  {
-   $contact->individual(Net::DRI::Util::xml_parse_boolean($c->textContent()));
-  } elsif ($name eq 'consentForPublishing')
-  {
-   $contact->consent_for_publishing(Net::DRI::Util::xml_parse_boolean($c->textContent()));
-  }
- }
- return;
+ my $eid=build_command_extension($mes,$epp,'extcon:info');
+ $mes->command_extension($eid,[['extcon:authInfo',['extcon:pw',$ep->{auth}->{pw}]]]);
 }
 
 ####################################################################################################
