@@ -1,7 +1,6 @@
 ## Domain Registry Interface, EPP NameStore Extension for Verisign
 ##
-## Copyright (c) 2006,2008,2009 Rony Meyer <perl@spot-light.ch>. All rights reserved.
-##               2010,2013,2016,2018-2019 Patrick Mevzek <netdri@dotandco.com>. All rights reserved.
+## Copyright (c) 2006 Rony Meyer <perl@spot-light.ch>. All rights reserved.
 ##
 ## This file is part of Net::DRI
 ##
@@ -11,15 +10,20 @@
 ## (at your option) any later version.
 ##
 ## See the LICENSE file that comes with this distribution for more details.
+#
+# 
+#
 ####################################################################################################
 
 package Net::DRI::Protocol::EPP::Extensions::VeriSign::NameStore;
 
 use strict;
-use warnings;
-use feature 'state';
 
 use Net::DRI::Util;
+use Net::DRI::Exception;
+
+our $VERSION=do { my @r=(q$Revision: 1.2 $=~/\d+/g); sprintf("%d".".%02d" x $#r, @r); };
+our $NS='http://www.verisign-grs.com/epp/namestoreExt-1.1';
 
 =pod
 
@@ -50,8 +54,7 @@ Patrick Mevzek, E<lt>netdri@dotandco.comE<gt>
 
 =head1 COPYRIGHT
 
-Copyright (c) 2006,2008,2009 Rony Meyer <perl@spot-light.ch>.
-          (c) 2010,2013,2016,2018-2019 Patrick Mevzek <netdri@dotandco.com>.
+Copyright (c) 2006 Rony Meyer <perl@spot-light.ch>.
 All rights reserved.
 
 This program is free software; you can redistribute it and/or modify
@@ -72,97 +75,81 @@ sub register_commands
  my %tmpDomain = (
            check  =>           [ \&add_namestore_ext, \&parse ],
            check_multi  =>     [ \&add_namestore_ext, \&parse ],
-           info   =>           [ \&add_namestore_ext, undef ],
-           transfer_query  =>  [ \&add_namestore_ext, undef ],
-           create =>           [ \&add_namestore_ext, undef ],
-           delete =>           [ \&add_namestore_ext, undef ],
-           renew =>            [ \&add_namestore_ext, undef ],
-           transfer_request => [ \&add_namestore_ext, undef ],
-           transfer_cancel  => [ \&add_namestore_ext, undef ],
-           transfer_answer  => [ \&add_namestore_ext, undef ],
-           update =>           [ \&add_namestore_ext, undef ],
+           info   =>           [ \&add_namestore_ext, \&parse_error ],
+           transfer_query  =>  [ \&add_namestore_ext, \&parse_error ],
+           create =>           [ \&add_namestore_ext, \&parse_error ],
+           delete =>           [ \&add_namestore_ext, \&parse_error ],
+           renew =>            [ \&add_namestore_ext, \&parse_error ],
+           transfer_request => [ \&add_namestore_ext, \&parse_error ],
+           transfer_cancel  => [ \&add_namestore_ext, \&parse_error ],
+           transfer_answer  => [ \&add_namestore_ext, \&parse_error ],
+           update =>           [ \&add_namestore_ext, \&parse_error ],
          );
 
  # host functions
  my %tmpHost = (
-           create       => [ \&add_namestore_ext, undef ],
+           create       => [ \&add_namestore_ext, \&parse_error ],
            check        => [ \&add_namestore_ext, \&parse ],
            check_multi  => [ \&add_namestore_ext, \&parse ],
-           info         => [ \&add_namestore_ext, undef ],
-           delete       => [ \&add_namestore_ext, undef ],
-           update       => [ \&add_namestore_ext, undef ],
+           info         => [ \&add_namestore_ext, \&parse_error ],
+           delete       => [ \&add_namestore_ext, \&parse_error ],
+           update       => [ \&add_namestore_ext, \&parse_error ],
          );
-
- # contact functions
- my %tmpContact = (
-           create       => [ \&add_namestore_ext, undef ],
-           check        => [ \&add_namestore_ext, \&parse ],
-           check_multi  => [ \&add_namestore_ext, \&parse ],
-           info         => [ \&add_namestore_ext, undef ],
-           delete       => [ \&add_namestore_ext, undef ],
-           update       => [ \&add_namestore_ext, undef ],
-         );
-
+ 
  return { 'domain' => \%tmpDomain,
           'host'   => \%tmpHost,
-          'contact'=> \%tmpContact,
-          'message' => { result => [ undef, \&parse_error ] },
         };
 }
 
-sub setup
-{
- my ($class,$po,$version)=@_;
- state $rns = { 'namestoreExt' => 'http://www.verisign-grs.com/epp/namestoreExt-1.1' };
- $po->ns($rns);
- return;
-}
-
 ####################################################################################################
 
 ########### Add the NameStore Extenstion to all domain & host commands
 
 sub add_namestore_ext
 {
- my ($epp,$domain,@p)=@_;
- my $rd=pop @p;
+ my $epp=shift(@_);
+ my $domain=shift(@_);
+ my $rd=pop(@_);
  my $mes=$epp->message();
  my $defprod=$epp->default_parameters()->{subproductid};
 
- if (Net::DRI::Util::has_key($rd,'subproductid') && $rd->{subproductid})
+ my $eid=$mes->command_extension_register('namestoreExt:namestoreExt',sprintf('xmlns:namestoreExt="%s" xsi:schemaLocation="%s namestoreExt-1.1.xsd"',$NS,$NS));
+
+ if (defined($rd) && (ref($rd) eq 'HASH') && exists($rd->{subproductid}) && $rd->{subproductid})
  {
-  $mes->command_extension('namestoreExt',['namestoreExt', ['subProduct', $rd->{subproductid}]]);
+  $mes->command_extension($eid,['namestoreExt:subProduct',$rd->{subproductid}]);
   return;
  }
 
  unless ($defprod eq '_auto_')
  {
-  $mes->command_extension('namestoreExt',['namestoreExt', ['subProduct', $defprod]]);
+  $mes->command_extension($eid,['namestoreExt:subProduct',$defprod]);
   return;
  }
 
- ## We do not know what will happen in case of check_multi with multiple TLDs
- my $ext='dotCOM';
- $domain=$domain->[0] if (ref($domain) eq 'ARRAY');
- $ext='dot'.uc($1) if ($domain=~m/\.(net|cc|tv|bz|jobs|edu)$/i);
-
- $mes->command_extension('namestoreExt',['namestoreExt', ['subProduct',$ext]]);
- return;
+ ## We do not know what will happen in case of check_multi with different TLD
+ if (ref($domain) eq 'ARRAY')
+ {
+  $mes->command_extension($eid,['namestoreExt:subProduct',($domain->[0]=~m/\.net$/i)? 'dotNET' : 'dotCOM']);
+ } else
+ {
+  $mes->command_extension($eid,['namestoreExt:subProduct',($domain=~m/\.net$/i)? 'dotNET' : 'dotCOM']);
+ }
 }
 
 sub parse
 {
  my ($po,$otype,$oaction,$oname,$rinfo)=@_;
  my $mes=$po->message();
+ parse_error($po,$otype,$oaction,$oname,$rinfo);
  return unless $mes->is_success();
 
- my $infdata=$mes->get_extension('namestoreExt','namestoreExt');
+ my $infdata=$mes->get_content('namestoreExt',$NS,1);
  return unless $infdata;
- my $c=$infdata->getChildrenByTagNameNS($mes->ns('namestoreExt'),'subProduct');
+ my $c=$infdata->getElementsByTagNameNS($NS,'subProduct');
  return unless $c;
 
- $rinfo->{$otype}->{$oname}->{subproductid}=$c->get_node(1)->textContent();
- return;
+ $rinfo->{$otype}->{$oname}->{subproductid}=$c->shift()->getFirstChild()->getData();
 }
 
 sub parse_error
@@ -171,17 +158,17 @@ sub parse_error
  my $mes=$po->message();
 
  ## Parse namestoreExt in case of errors
- return unless $mes->result_is('PARAMETER_VALUE_POLICY_ERROR') || $mes->result_is('COMMAND_SYNTAX_ERROR');
+ return unless $mes->errcode() == 2306;
 
- my $data=$mes->get_extension('namestoreExt','nsExtErrData');
- return unless defined $data;
- $data=$data->getChildrenByTagNameNS($mes->ns('namestoreExt'),'msg');
- return unless defined $data && $data->size();
- $data=$data->get_node(1);
+ my $ext=$mes->node_extension();
+ my $data=$ext->getElementsByTagNameNS($NS,'nsExtErrData');
+ return unless $data;
+ $data=$data->shift()->getElementsByTagNameNS($NS,'msg');
+ return unless $data;
+ $data=$data->shift();
 
- ## We add it to the latest status extra_info seen.
- $mes->add_to_extra_info({from => 'verisign:namestoreExt', type => 'text', message => $data->textContent(), code => $data->getAttribute('code')});
- return;
+ ## It would be great to be able to put that somewhere in ResultStatus !
+ push @{$mes->{result_extra_info}},sprintf('%s (code=%d)',$data->getFirstChild()->getData(),$data->getAttribute('code'));
 }
 
 #########################################################################################################
