@@ -1,6 +1,6 @@
 ## Domain Registry Interface, EPP Low Balance (EPP-LowBalance-Mapping.pdf)
 ##
-## Copyright (c) 2006-2008,2013,2018 Patrick Mevzek <netdri@dotandco.com>. All rights reserved.
+## Copyright (c) 2006 Patrick Mevzek <netdri@dotandco.com>. All rights reserved.
 ##
 ## This file is part of Net::DRI
 ##
@@ -10,16 +10,19 @@
 ## (at your option) any later version.
 ##
 ## See the LICENSE file that comes with this distribution for more details.
+#
+# 
+#
 ####################################################################################################
 
 package Net::DRI::Protocol::EPP::Extensions::VeriSign::PollLowBalance;
 
 use strict;
-use warnings;
-use feature 'state';
 
 use Net::DRI::Util;
 
+our $VERSION=do { my @r=(q$Revision: 1.1 $=~/\d+/g); sprintf("%d".".%02d" x $#r, @r); };
+
 =pod
 
 =head1 NAME
@@ -48,7 +51,7 @@ Patrick Mevzek, E<lt>netdri@dotandco.comE<gt>
 
 =head1 COPYRIGHT
 
-Copyright (c) 2006-2008,2013,2018 Patrick Mevzek <netdri@dotandco.com>.
+Copyright (c) 2006 Patrick Mevzek <netdri@dotandco.com>.
 All rights reserved.
 
 This program is free software; you can redistribute it and/or modify
@@ -60,6 +63,7 @@ See the LICENSE file that comes with this distribution for more details.
 
 =cut
 
+
 ####################################################################################################
 
 sub register_commands
@@ -72,15 +76,6 @@ sub register_commands
  return { 'message' => \%tmp };
 }
 
-sub setup
-{
- my ($class,$po,$version)=@_;
-
- state $ns = { 'lowbalance' => 'http://www.verisign.com/epp/lowbalance-poll-1.0' };
- $po->ns($ns);
- return;
-}
-
 ####################################################################################################
 
 sub parse
@@ -89,14 +84,13 @@ sub parse
  my $mes=$po->message();
  return unless $mes->is_success();
 
- my $infdata=$mes->get_response('lowbalance','pollData');
+ my $infdata=$mes->get_content('pollData','http://www.verisign.com/epp/lowbalance-poll-1.0',0);
  return unless $infdata;
 
  my %w=(action => 'lowbalance_notification');
  my $c=$infdata->getFirstChild();
  while ($c)
  {
-  next unless ($c->nodeType() == 1); ## only for element nodes
   my $name=$c->localname() || $c->nodeName();
   next unless $name;
 
@@ -108,10 +102,10 @@ sub parse
    $w{Net::DRI::Util::remcam($name)}=$c->getFirstChild()->getData();
    $w{'credit_threshold_type'}=$c->getAttribute('type');
   }
- } continue { $c=$c->getNextSibling(); }
+  $c=$c->getNextSibling();
+ }
 
  $rinfo->{session}->{lowbalance}=\%w;
- return;
 }
 
 ####################################################################################################
