@@ -22,7 +22,7 @@ use strict;
 use Net::DRI::Util;
 use Net::DRI::Exception;
 
-our $VERSION=do { my @r=(q$Revision: 1.2 $=~/\d+/g); sprintf("%d".".%02d" x $#r, @r); };
+our $VERSION=do { my @r=(q$Revision: 1.3 $=~/\d+/g); sprintf("%d".".%02d" x $#r, @r); };
 
 =pod
 
@@ -84,11 +84,25 @@ sub info
  my ($epp,$domain,$rd)=@_;
  my $mes=$epp->message();
 
- Net::DRI::Exception::usererr_insufficient_parameters('Whois Info must be provided') unless (defined($rd) && (ref($rd) && 'HASH') && exists($rd->{whois_info}));
- Net::DRI::Exception::usererr_invalid_parameters('Whois Info must be true/false/1/0') unless Net::DRI::Util::xml_is_boolean($rd->{whois_info});
+ my $wi;
+ if (defined($rd) && (ref($rd) && 'HASH') && exists($rd->{whois_info}))
+ {
+  $wi=$rd->{whois_info};
+ } else
+ {
+  my $def=$epp->default_parameters();
+  if ($def && (ref($def) eq 'HASH') && exists($def->{whois_info}))
+  {
+   $wi=$def->{whois_info};
+  } else
+  {
+   Net::DRI::Exception::usererr_insufficient_parameters('Whois Info must be provided');
+  }
+ }
+ Net::DRI::Exception::usererr_invalid_parameters('Whois Info must be true/false/1/0') unless Net::DRI::Util::xml_is_boolean($wi);
  
  my $eid=$mes->command_extension_register('whoisInf:whoisInf','xmlns:whoisInf="http://www.verisign.com/epp/whoisInf-1.0" xsi:schemaLocation="http://www.verisign.com/epp/whoisInf-1.0 whoisInf-1.0.xsd"');
- $mes->command_extension($eid,['whoisInf:flag',$rd->{whois_info}]);
+ $mes->command_extension($eid,['whoisInf:flag',$wi]);
 }
 
 sub info_parse
