@@ -1,6 +1,6 @@
-## Domain Registry Interface, Whois Protocol (RFC3912)
+## Domain Registry Interface, Whois Protocol
 ##
-## Copyright (c) 2007-2010,2013 Patrick Mevzek <netdri@dotandco.com>. All rights reserved.
+## Copyright (c) 2007 Patrick Mevzek <netdri@dotandco.com>. All rights reserved.
 ##
 ## This file is part of Net::DRI
 ##
@@ -10,12 +10,14 @@
 ## (at your option) any later version.
 ##
 ## See the LICENSE file that comes with this distribution for more details.
+#
+# 
+#
 ####################################################################################################
 
 package Net::DRI::Protocol::Whois;
 
 use strict;
-use warnings;
 
 use base qw(Net::DRI::Protocol);
 
@@ -23,11 +25,13 @@ use Net::DRI::Util;
 use Net::DRI::Exception;
 use Net::DRI::Protocol::Whois::Message;
 
+our $VERSION=do { my @r=(q$Revision: 1.1 $=~/\d+/g); sprintf("%d".".%02d" x $#r, @r); };
+
 =pod
 
 =head1 NAME
 
-Net::DRI::Protocol::Whois - Whois Protocol (RFC3912) for Net::DRI
+Net::DRI::Protocol::Whois - Whois Protocol for Net::DRI
 
 =head1 DESCRIPTION
 
@@ -51,7 +55,7 @@ Patrick Mevzek, E<lt>netdri@dotandco.comE<gt>
 
 =head1 COPYRIGHT
 
-Copyright (c) 2007-2010,2013 Patrick Mevzek <netdri@dotandco.com>.
+Copyright (c) 2007 Patrick Mevzek <netdri@dotandco.com>.
 All rights reserved.
 
 This program is free software; you can redistribute it and/or modify
@@ -67,32 +71,30 @@ See the LICENSE file that comes with this distribution for more details.
 
 sub new
 {
- my ($c,$ctx,$rp)=@_;
- my $drd=$ctx->{registry}->driver();
- my $self=$c->SUPER::new($ctx);
- $self->name('whois');
- my $version=Net::DRI::Util::check_equal($rp->{version},['1.0'],'1.0');
+ my $h=shift;
+ my $c=ref($h) || $h;
+
+ my ($drd,$version,$extrah)=@_;
+
+ my $self=$c->SUPER::new(); ## we are now officially a Net::DRI::Protocol object
+ $self->name('Whois');
+ $version=Net::DRI::Util::check_equal($version,['1.0'],'1.0');
  $self->version($version);
 
+ bless($self,$c); ## rebless
+
  my @tlds=$drd->tlds();
-## Net::DRI::Exception::usererr_invalid_parameters('Whois can not be used for registry handling multiple TLDs: '.join(',',@tlds)) unless (@tlds==1 || lc($tlds[0]) eq 'com');
- $drd->set_factories($self) if $drd->can('set_factories');
- $self->factories('message',sub { return Net::DRI::Protocol::Whois::Message->new(@_)->version($version); });
- $self->_load(uc($tlds[0]));
+ Net::DRI::Exception::usererr_invalid_parameters('Whois can not be used for registry handling multiple TLDs: '.join(',',@tlds)) unless (@tlds==1 || lc($tlds[0]) eq 'com');
+ $self->factories({ message => sub { return Net::DRI::Protocol::Whois::Message->new(@_)->version($version); } });
+ $self->_load(uc($tlds[0]),$extrah);
  return $self;
 }
 
 sub _load
 {
- my ($self,$tld)=@_;
- return $self->SUPER::_load('Net::DRI::Protocol::Whois::Domain::'.$tld);
+ my ($self,$tld,$extrah)=@_;
+ $self->SUPER::_load('Net::DRI::Protocol::Whois::Domain::'.$tld);
 }
 
-sub transport_default
-{
- my ($self)=@_;
- return (protocol_connection => 'Net::DRI::Protocol::Whois::Connection', protocol_version => 1);
-}
-
-####################################################################################################
+############################################################################################
 1;
