@@ -1,6 +1,6 @@
-## Domain Registry Interface, Whois commands for .AERO (RFC3912)
+## Domain Registry Interface, Whois parse for .AERO (RFC3912)
 ##
-## Copyright (c) 2007,2009,2013 Patrick Mevzek <netdri@dotandco.com>. All rights reserved.
+## Copyright (c) 2007 Patrick Mevzek <netdri@dotandco.com>. All rights reserved.
 ##
 ## This file is part of Net::DRI
 ##
@@ -10,23 +10,27 @@
 ## (at your option) any later version.
 ##
 ## See the LICENSE file that comes with this distribution for more details.
+#
+# 
+#
 ####################################################################################################
 
 package Net::DRI::Protocol::Whois::Domain::AERO;
 
 use strict;
-use warnings;
 
 use Net::DRI::Exception;
 use Net::DRI::Util;
 use Net::DRI::Protocol::Whois::Domain::common;
 use Net::DRI::Data::Contact::AERO;
 
+our $VERSION=do { my @r=(q$Revision: 1.1 $=~/\d+/g); sprintf("%d".".%02d" x $#r, @r); };
+
 =pod
 
 =head1 NAME
 
-Net::DRI::Protocol::Whois::Domain::AERO - .AERO Whois commands (RFC3912) for Net::DRI
+Net::DRI::Protocol::Whois::Domain::AERO - Whois .AERO parse (RFC3912) for Net::DRI
 
 =head1 DESCRIPTION
 
@@ -50,7 +54,7 @@ Patrick Mevzek, E<lt>netdri@dotandco.comE<gt>
 
 =head1 COPYRIGHT
 
-Copyright (c) 2007,2009,2013 Patrick Mevzek <netdri@dotandco.com>.
+Copyright (c) 2007 Patrick Mevzek <netdri@dotandco.com>.
 All rights reserved.
 
 This program is free software; you can redistribute it and/or modify
@@ -74,9 +78,8 @@ sub info
 {
  my ($po,$domain,$rd)=@_;
  my $mes=$po->message();
- Net::DRI::Exception->die(1,'protocol/whois',10,'Invalid domain name: '.$domain) unless Net::DRI::Util::is_hostname($domain);
+ Net::DRI::Exception->die(1,'protocol/DAS',10,'Invalid domain name: '.$domain) unless Net::DRI::Util::is_hostname($domain);
  $mes->command('domain '.lc($domain));
- return;
 }
 
 sub info_parse
@@ -87,23 +90,22 @@ sub info_parse
 
  my $rr=$mes->response();
  my $rd=$mes->response_raw();
- my ($domain,$exist)=parse_domain($po,$rr,$rd,$rinfo);
+ my ($domain,$exist)=parse_domain($rr,$rd,$rinfo);
  $rinfo->{domain}->{$domain}->{exist}=$exist;
  $rinfo->{domain}->{$domain}->{action}='info';
 
  return unless $exist;
 
- Net::DRI::Protocol::Whois::Domain::common::epp_parse_registrars($po,$domain,$rr,$rinfo);
- Net::DRI::Protocol::Whois::Domain::common::epp_parse_dates($po,$domain,$rr,$rinfo);
- Net::DRI::Protocol::Whois::Domain::common::epp_parse_status($po,$domain,$rr,$rinfo);
- Net::DRI::Protocol::Whois::Domain::common::epp_parse_contacts($po,$domain,$rr,$rinfo,{registrant => 'Registrant',admin => 'Admin', billing => 'Billing', tech => 'Tech'});
- Net::DRI::Protocol::Whois::Domain::common::epp_parse_ns($po,$domain,$rr,$rinfo);
- return;
+ Net::DRI::Protocol::Whois::Domain::common::epp_parse_registrars($domain,$rr,$rinfo);
+ Net::DRI::Protocol::Whois::Domain::common::epp_parse_dates($domain,$rr,$rinfo);
+ Net::DRI::Protocol::Whois::Domain::common::epp_parse_status($domain,$rr,$rinfo);
+ Net::DRI::Protocol::Whois::Domain::common::epp_parse_contacts($domain,$rr,$rinfo,{registrant => 'Registrant',admin => 'Admin', billing => 'Billing', tech => 'Tech'},sub { return Net::DRI::Data::Contact::AERO->new() });
+ Net::DRI::Protocol::Whois::Domain::common::epp_parse_ns($domain,$rr,$rinfo);
 }
 
 sub parse_domain
 {
- my ($po,$rr,$rd,$rinfo)=@_;
+ my ($rr,$rd,$rinfo)=@_;
  my ($dom,$e);
  if (exists($rr->{'Domain Name'}))
  {
