@@ -1,6 +1,6 @@
-## Domain Registry Interface, Whois commands for .COM/.NET (RFC3912)
+## Domain Registry Interface, Whois parse for .COM (RFC3912)
 ##
-## Copyright (c) 2007,2009,2013 Patrick Mevzek <netdri@dotandco.com>. All rights reserved.
+## Copyright (c) 2007 Patrick Mevzek <netdri@dotandco.com>. All rights reserved.
 ##
 ## This file is part of Net::DRI
 ##
@@ -10,22 +10,29 @@
 ## (at your option) any later version.
 ##
 ## See the LICENSE file that comes with this distribution for more details.
+#
+# 
+#
 ####################################################################################################
 
 package Net::DRI::Protocol::Whois::Domain::COM;
 
 use strict;
-use warnings;
 
 use Net::DRI::Exception;
 use Net::DRI::Util;
+use Net::DRI::Data::Hosts;
 use Net::DRI::Protocol::EPP::Core::Status;
 
+use DateTime::Format::Strptime;
+
+our $VERSION=do { my @r=(q$Revision: 1.1 $=~/\d+/g); sprintf("%d".".%02d" x $#r, @r); };
+
 =pod
 
 =head1 NAME
 
-Net::DRI::Protocol::Whois::Domain::COM - .COM/.NET Whois commands (RFC3912) for Net::DRI
+Net::DRI::Protocol::Whois::Domain::COM - Whois .COM parse (RFC3912) for Net::DRI
 
 =head1 DESCRIPTION
 
@@ -49,7 +56,7 @@ Patrick Mevzek, E<lt>netdri@dotandco.comE<gt>
 
 =head1 COPYRIGHT
 
-Copyright (c) 2007,2009,2013 Patrick Mevzek <netdri@dotandco.com>.
+Copyright (c) 2007 Patrick Mevzek <netdri@dotandco.com>.
 All rights reserved.
 
 This program is free software; you can redistribute it and/or modify
@@ -73,9 +80,8 @@ sub info
 {
  my ($po,$domain,$rd)=@_;
  my $mes=$po->message();
- Net::DRI::Exception->die(1,'protocol/whois',10,'Invalid domain name: '.$domain) unless Net::DRI::Util::is_hostname($domain);
+ Net::DRI::Exception->die(1,'protocol/DAS',10,'Invalid domain name: '.$domain) unless Net::DRI::Util::is_hostname($domain);
  $mes->command('domain '.lc($domain));
- return;
 }
 
 sub info_parse
@@ -86,22 +92,21 @@ sub info_parse
 
  my $rr=$mes->response();
  my $rd=$mes->response_raw();
- my ($domain,$exist)=parse_domain($po,$rr,$rd,$rinfo);
+ my ($domain,$exist)=parse_domain($rr,$rd,$rinfo);
  $rinfo->{domain}->{$domain}->{exist}=$exist;
  $rinfo->{domain}->{$domain}->{action}='info';
 
  return unless $exist;
 
- parse_registrars($po,$domain,$rr,$rinfo);
- parse_dates($po,$domain,$rr,$rinfo);
- parse_status($po,$domain,$rr,$rinfo);
- parse_ns($po,$domain,$rr,$rinfo);
- return;
+ parse_registrars($domain,$rr,$rinfo);
+ parse_dates($domain,$rr,$rinfo);
+ parse_status($domain,$rr,$rinfo);
+ parse_ns($domain,$rr,$rinfo);
 }
 
 sub parse_domain
 {
- my ($po,$rr,$rd,$rinfo)=@_;
+ my ($rr,$rd,$rinfo)=@_;
  my ($dom,$e);
  if (exists($rr->{'Domain Name'}))
  {
@@ -118,39 +123,36 @@ sub parse_domain
 
 sub parse_registrars
 {
- my ($po,$domain,$rr,$rinfo)=@_;
+ my ($domain,$rr,$rinfo)=@_;
  $rinfo->{domain}->{$domain}->{clName}=$rr->{'Registrar'}->[0];
  $rinfo->{domain}->{$domain}->{clWhois}=$rr->{'Whois Server'}->[0];
  $rinfo->{domain}->{$domain}->{clWebsite}=$rr->{'Referral URL'}->[0];
- return;
 }
 
 sub parse_dates
 {
- my ($po,$domain,$rr,$rinfo)=@_;
- my $strp=$po->build_strptime_parser(pattern => '%d-%b-%Y', locale => 'en_US', time_zone => 'America/New_York');
+ my ($domain,$rr,$rinfo)=@_;
+ my $strp=DateTime::Format::Strptime->new(pattern => '%d-%b-%Y', locale => 'en_US', time_zone => 'America/New_York');
  $rinfo->{domain}->{$domain}->{crDate}=$strp->parse_datetime($rr->{'Creation Date'}->[0]);
  $rinfo->{domain}->{$domain}->{upDate}=$strp->parse_datetime($rr->{'Updated Date'}->[0]);
  $rinfo->{domain}->{$domain}->{exDate}=$strp->parse_datetime($rr->{'Expiration Date'}->[0]);
 
  my ($l)=($rr->{'>>> Last update of whois database'}->[0]=~m/^(.+) <<<$/);
- $strp=$po->build_strptime_parser(pattern => '%a, %d %b %Y %T UTC', locale => 'en_US', time_zone => 'UTC');
+ $strp->time_zone('UTC');
+ $strp->pattern('%a, %d %b %Y %T UTC');
  $rinfo->{domain}->{$domain}->{wuDate}=$strp->parse_datetime($l);
- return;
 }
 
 sub parse_status
 {
- my ($po,$domain,$rr,$rinfo)=@_;
- $rinfo->{domain}->{$domain}->{status}=Net::DRI::Protocol::EPP::Core::Status->new($rr->{'Status'}); #####
- return;
+ my ($domain,$rr,$rinfo)=@_;
+ $rinfo->{domain}->{$domain}->{status}=Net::DRI::Protocol::EPP::Core::Status->new($rr->{'Status'});
 }
 
 sub parse_ns
 {
- my ($po,$domain,$rr,$rinfo)=@_;
- $rinfo->{domain}->{$domain}->{ns}=$po->create_local_object('hosts')->set(@{$rr->{'Name Server'}}) if exists($rr->{'Name Server'});
- return;
+ my ($domain,$rr,$rinfo)=@_;
+ $rinfo->{domain}->{$domain}->{ns}=Net::DRI::Data::Hosts->new_set(@{$rr->{'Name Server'}}) if exists($rr->{'Name Server'});
 }
 
 ####################################################################################################
