@@ -1,6 +1,6 @@
-## Domain Registry Interface, Whois commands for .EU (RFC3912)
+## Domain Registry Interface, Whois parse for .EU (RFC3912)
 ##
-## Copyright (c) 2007,2009,2010,2013 Patrick Mevzek <netdri@dotandco.com>. All rights reserved.
+## Copyright (c) 2007 Patrick Mevzek <netdri@dotandco.com>. All rights reserved.
 ##
 ## This file is part of Net::DRI
 ##
@@ -10,24 +10,29 @@
 ## (at your option) any later version.
 ##
 ## See the LICENSE file that comes with this distribution for more details.
+#
+# 
+#
 ####################################################################################################
 
 package Net::DRI::Protocol::Whois::Domain::EU;
 
 use strict;
-use warnings;
 
 use Net::DRI::Exception;
 use Net::DRI::Util;
-use Net::DRI::Protocol::ResultStatus;
-
+use Net::DRI::Data::Hosts;
 use Net::DRI::Protocol::EPP::Core::Status;
 
+use DateTime::Format::Strptime;
+
+our $VERSION=do { my @r=(q$Revision: 1.1 $=~/\d+/g); sprintf("%d".".%02d" x $#r, @r); };
+
 =pod
 
 =head1 NAME
 
-Net::DRI::Protocol::Whois::Domain::EU - .EU Whois commands (RFC3912) for Net::DRI
+Net::DRI::Protocol::Whois::Domain::EU - Whois .EU parse (RFC3912) for Net::DRI
 
 =head1 DESCRIPTION
 
@@ -51,7 +56,7 @@ Patrick Mevzek, E<lt>netdri@dotandco.comE<gt>
 
 =head1 COPYRIGHT
 
-Copyright (c) 2007,2009,2010,2013 Patrick Mevzek <netdri@dotandco.com>.
+Copyright (c) 2007 Patrick Mevzek <netdri@dotandco.com>.
 All rights reserved.
 
 This program is free software; you can redistribute it and/or modify
@@ -75,9 +80,8 @@ sub info
 {
  my ($po,$domain,$rd)=@_;
  my $mes=$po->message();
- Net::DRI::Exception->die(1,'protocol/whois',10,'Invalid domain name: '.$domain) unless Net::DRI::Util::is_hostname($domain);
- $mes->command(lc $domain);
- return;
+ Net::DRI::Exception->die(1,'protocol/DAS',10,'Invalid domain name: '.$domain) unless Net::DRI::Util::is_hostname($domain);
+ $mes->command('domain '.lc($domain));
 }
 
 sub info_parse
@@ -88,67 +92,57 @@ sub info_parse
 
  my $rr=$mes->response();
  my $rd=$mes->response_raw();
- die(Net::DRI::Protocol::ResultStatus->new_error('SESSION_LIMIT_EXCEEDED_CLOSING','Registry rate limiting','en')) if $rd=~m/Still in grace period, wait/;
- my ($domain,$exist)=parse_domain($po,$rr,$rd,$rinfo);
+ my ($domain,$exist)=parse_domain($rr,$rd,$rinfo);
  $rinfo->{domain}->{$domain}->{exist}=$exist;
  $rinfo->{domain}->{$domain}->{action}='info';
- $rinfo->{domain}->{$domain}->{ace}=$rr->{'IDNA Domain'}.'.eu' if exists $rr->{'IDNA Domain'};
 
  return unless $exist;
 
- parse_registrars($po,$domain,$rr,$rinfo);
- parse_dates($po,$domain,$rr,$rinfo);
- parse_status($po,$domain,$rr,$rinfo);
- parse_ns($po,$domain,$rr,$rd,$rinfo);
- return;
+ parse_registrars($domain,$rr,$rinfo);
+ parse_dates($domain,$rr,$rinfo);
+ parse_status($domain,$rr,$rinfo);
+ parse_ns($domain,$rr,$rd,$rinfo);
 }
 
 sub parse_domain
 {
- my ($po,$rr,$rd,$rinfo)=@_;
- my $dom=lc($rr->{'Domain'}->[0]).'.eu';
- my $e=(exists($rr->{'Status'}) && ($rr->{'Status'}->[0] eq 'AVAILABLE'))? 0 : 1;
- return ($dom,$e);
+ my ($rr,$rd,$rinfo)=@_;
+ my ($dom,$e);
+ $dom=lc($rr->{'Domain'}->[0]).'.eu';
+ $e=($rr->{'Status'}->[0] eq 'FREE')? 0 : 1;
+ return (lc($dom),$e);
 }
 
 sub parse_registrars
 {
- my ($po,$domain,$rr,$rinfo)=@_;
- $rinfo->{domain}->{$domain}->{clName}=$rr->{'Name'}->[-1];
- $rinfo->{domain}->{$domain}->{clWebsite}=$rr->{'Website'}->[-1] if exists $rr->{'Website'};
- return;
+ my ($domain,$rr,$rinfo)=@_;
+ $rinfo->{domain}->{$domain}->{clName}=$rr->{'Name'}->[0];
+ $rinfo->{domain}->{$domain}->{clWebsite}=$rr->{'Website'}->[0];
 }
 
 sub parse_dates
 {
- my ($po,$domain,$rr,$rinfo)=@_;
- return unless exists $rr->{'Registered'};
- my $strp=$po->build_strptime_parser(pattern => '%a %b%n%d %Y', locale => 'en_US', time_zone => 'Europe/Brussels');
+ my ($domain,$rr,$rinfo)=@_;
+ my $strp=DateTime::Format::Strptime->new(pattern => '%a %b%n%d %Y', locale => 'en_US', time_zone => 'Europe/Brussels');
  $rinfo->{domain}->{$domain}->{crDate}=$strp->parse_datetime($rr->{'Registered'}->[0]);
- return;
 }
 
 sub parse_status
 {
- my ($po,$domain,$rr,$rinfo)=@_;
+ my ($domain,$rr,$rinfo)=@_;
  $rinfo->{domain}->{$domain}->{status}=Net::DRI::Protocol::EPP::Core::Status->new(['ok']);
- return;
 }
 
 sub parse_ns
 {
- my ($po,$domain,$rr,$rd,$rinfo)=@_;
- my $ns=$po->create_local_object('hosts');
+ my ($domain,$rr,$rd,$rinfo)=@_;
+ my @ns;
  foreach my $l (@$rd)
  {
   next unless (($l=~m/^Nameservers:/)..($l=~m/^\s*$/));
-  $l=~s/^\s+//;
-  $l=~s/[)\s]+$//;
-  next unless length($l);
-  $ns->add(split(/ \(?/,$l));
+  push @ns,$1 if ($l=~m/^\s*(\S+)/);
  }
- $rinfo->{domain}->{$domain}->{ns}=$ns;
- return;
+ $rinfo->{domain}->{$domain}->{ns}=Net::DRI::Data::Hosts->new_set(@ns) if @ns;
 }
 
 ####################################################################################################
