@@ -1,6 +1,6 @@
 ## Domain Registry Interface, Whois common parse subroutines
 ##
-## Copyright (c) 2007-2009,2012-2013 Patrick Mevzek <netdri@dotandco.com>. All rights reserved.
+## Copyright (c) 2007 Patrick Mevzek <netdri@dotandco.com>. All rights reserved.
 ##
 ## This file is part of Net::DRI
 ##
@@ -10,20 +10,29 @@
 ## (at your option) any later version.
 ##
 ## See the LICENSE file that comes with this distribution for more details.
+#
+# 
+#
 ####################################################################################################
 
 package Net::DRI::Protocol::Whois::Domain::common;
 
 use strict;
-use warnings;
 
+use Net::DRI::Data::Hosts;
+use Net::DRI::Data::Contact;
+use Net::DRI::Data::ContactSet;
 use Net::DRI::Protocol::EPP::Core::Status;
 
+use DateTime::Format::Strptime;
+
+our $VERSION=do { my @r=(q$Revision: 1.1 $=~/\d+/g); sprintf("%d".".%02d" x $#r, @r); };
+
 =pod
 
 =head1 NAME
 
-Net::DRI::Protocol::Whois::Domain::common - Whois commands (RFC3912) for Net::DRI
+Net::DRI::Protocol::Whois::Domain::common - Whois common parse for Net::DRI
 
 =head1 DESCRIPTION
 
@@ -47,7 +56,7 @@ Patrick Mevzek, E<lt>netdri@dotandco.comE<gt>
 
 =head1 COPYRIGHT
 
-Copyright (c) 2007-2009,2012-2013 Patrick Mevzek <netdri@dotandco.com>.
+Copyright (c) 2007 Patrick Mevzek <netdri@dotandco.com>.
 All rights reserved.
 
 This program is free software; you can redistribute it and/or modify
@@ -63,12 +72,10 @@ See the LICENSE file that comes with this distribution for more details.
 
 sub epp_parse_registrars
 {
- my ($po,$domain,$rr,$rinfo)=@_;
+ my ($domain,$rr,$rinfo)=@_;
  my %t=('Sponsoring Registrar' => 'cl',
         'Created By'           => 'cr',
-        'Created by Registrar' => 'cr',
         'Updated By'           => 'up',
-        'Last Updated by Registrar' => 'up',
        );
 
  while(my ($whois,$epp)=each(%t))
@@ -84,15 +91,13 @@ sub epp_parse_registrars
    $rinfo->{domain}->{$domain}->{$epp.'ID'}=$s;
   }
  }
- return;
 }
 
 sub epp_parse_dates
 {
- my ($po,$domain,$rr,$rinfo)=@_;
- my $strp=$po->build_strptime_parser(pattern => '%d-%b-%Y %T UTC', locale => 'en_US', time_zone => 'UTC');
+ my ($domain,$rr,$rinfo)=@_;
+ my $strp=DateTime::Format::Strptime->new(pattern => '%d-%b-%Y %T UTC', locale => 'en_US', time_zone => 'UTC');
  $rinfo->{domain}->{$domain}->{crDate}=$strp->parse_datetime($rr->{'Created On'}->[0]);
-
  foreach my $k ('Updated On','Last Updated On')
  {
   next unless exists($rr->{$k});
@@ -105,72 +110,69 @@ sub epp_parse_dates
   $rinfo->{domain}->{$domain}->{exDate}=$strp->parse_datetime($rr->{$k}->[0]);
   last;
  }
- return;
 }
 
 sub epp_parse_status
 {
- my ($po,$domain,$rr,$rinfo)=@_;
- my @s;
- if (exists($rr->{'Domain Status'}))
+ my ($domain,$rr,$rinfo)=@_;
+ my @s=map { s/OK/ok/; $_; } @{$rr->{'Domain Status'}};
+ if (@s)
  {
-  @s=map { my $s=$_; $s=~s/OK/ok/; $s; } @{$rr->{'Domain Status'}};
- } elsif (exists($rr->{'Status'})) ## .ORG/.INFO/.MOBI/.CAT variation
- {
-  @s=map { my $t=lc($_); $t=~s/ (.)/uc($1)/eg; $t; } @{$rr->{'Status'}};
+  $rinfo->{domain}->{$domain}->{status}=Net::DRI::Protocol::EPP::Core::Status->new(\@s);
+  return;
  }
+ ## .ORG/.INFO variation
+ @s=map { my $t=lc($_); $t=~s/ (.)/uc($1)/eg; $t; } @{$rr->{'Status'}};
  $rinfo->{domain}->{$domain}->{status}=Net::DRI::Protocol::EPP::Core::Status->new(\@s) if @s;
- return;
 }
 
 sub epp_parse_contacts
 {
- my ($po,$domain,$rr,$rinfo,$rh)=@_;
- my $cs=$po->create_local_object('contactset');
- while(my ($type,$whois)=each %$rh)
+ my ($domain,$rr,$rinfo,$rh,$f)=@_;
+ my $cs=Net::DRI::Data::ContactSet->new();
+ while(my ($type,$whois)=each(%$rh))
  {
-  my $c=$po->create_local_object('contact');
-  $c->srid($rr->{$whois.' ID'}->[0]) if (exists $rr->{$whois.' ID'} && length $rr->{$whois.' ID'}->[0]);
-  $c->name($rr->{$whois.' Name'}->[0]) if (exists $rr->{$whois.' Name'} && length $rr->{$whois.' Name'}->[0]);
-  $c->org($rr->{$whois.' Organization'}->[0]) if (exists $rr->{$whois.' Organization'} && length $rr->{$whois.' Organization'}->[0]);
+  my $c=(defined($f) && ref($f) eq 'CODE')? $f->() : Net::DRI::Data::Contact->new();
+  $c->roid($rr->{$whois.' ID'}->[0]) if (exists($rr->{$whois.' ID'}) && $rr->{$whois.' ID'}->[0]);
+  $c->name($rr->{$whois.' Name'}->[0]) if (exists($rr->{$whois.' Name'}) && $rr->{$whois.' Name'}->[0]);
+  $c->org($rr->{$whois.' Organization'}->[0]) if (exists($rr->{$whois.' Organization'}) && $rr->{$whois.' Organization'}->[0]);
   my @s;
   foreach my $st (qw/Street Address/) ## 2nd form needed for .BIZ
   {
    my $k=$whois.' '.$st;
-   @s=map { $rr->{$k.$_}->[0] } grep { exists $rr->{$k.$_} && length $rr->{$k.$_}->[0] } (1..3);
+   @s=map { $rr->{$k.$_}->[0] } grep { exists($rr->{$k.$_}) && $rr->{$k.$_}->[0] } (1..3);
    next unless @s;
    $c->street(\@s);
    last;
   }
-  $c->city($rr->{$whois.' City'}->[0]) if (exists $rr->{$whois.' City'} && length $rr->{$whois.' City'}->[0]);
-  $c->sp($rr->{$whois.' State/Province'}->[0]) if (exists $rr->{$whois.' State/Province'} && length $rr->{$whois.' State/Province'}->[0]);
-  $c->pc($rr->{$whois.' Postal Code'}->[0]) if (exists $rr->{$whois.' Postal Code'} && length $rr->{$whois.' Postal Code'}->[0]);
-  $c->cc($rr->{$whois.' Country'}->[0]) if (exists $rr->{$whois.' Country'} && length $rr->{$whois.' Country'}->[0]);
+  $c->city($rr->{$whois.' City'}->[0]) if (exists($rr->{$whois.' City'}) && $rr->{$whois.' City'}->[0]);
+  $c->sp($rr->{$whois.' State/Province'}->[0]) if (exists($rr->{$whois.' State/Province'}) && $rr->{$whois.' State/Province'}->[0]);
+  $c->pc($rr->{$whois.' Postal Code'}->[0]) if (exists($rr->{$whois.' Postal Code'}) && $rr->{$whois.' Postal Code'}->[0]);
+  $c->cc($rr->{$whois.' Country'}->[0]) if (exists($rr->{$whois.' Country'}) && $rr->{$whois.' Country'}->[0]);
   my $t;
   foreach my $st ('Phone','Phone Number') ## 2nd form needed for .BIZ
   {
-   $t=epp_parse_tel($po,$rr,$whois.' '.$st);
+   $t=epp_parse_tel($rr,$whois.' '.$st);
    next unless $t;
    $c->voice($t);
    last;
   }
   foreach my $st ('FAX','Facsimile Number') ## 2nd form needed for .BIZ
   {
-   $t=epp_parse_tel($po,$rr,$whois.' '.$st);
+   $t=epp_parse_tel($rr,$whois.' '.$st);
    next unless $t;
    $c->fax($t);
    last;
   }
-  $c->email($rr->{$whois.' Email'}->[0]) if (exists $rr->{$whois.' Email'} && length $rr->{$whois.' Email'}->[0]);
-  $cs->add($c,$type) if grep { length } ($c->srid(),$c->name(),$c->city(),$c->cc(),$c->email());
+  $c->email($rr->{$whois.' Email'}->[0]) if (exists($rr->{$whois.' Email'}) && $rr->{$whois.' Email'}->[0]);
+  $cs->add($c,$type);
  }
  $rinfo->{domain}->{$domain}->{contact}=$cs;
- return;
 }
 
 sub epp_parse_tel
 {
- my ($po,$rr,$key)=@_;
+ my ($rr,$key)=@_;
  return '' unless (exists($rr->{$key}) && $rr->{$key}->[0]);
  my $r=$rr->{$key}->[0];
  $r.='x'.$rr->{$key.' Ext.'}->[0] if (exists($rr->{$key.' Ext.'}) && $rr->{$key.' Ext.'}->[0]);
@@ -179,11 +181,9 @@ sub epp_parse_tel
 
 sub epp_parse_ns
 {
- my ($po,$domain,$rr,$rinfo)=@_;
- return unless (exists($rr->{'Name Server'}));
+ my ($domain,$rr,$rinfo)=@_;
  my @ns=grep { defined($_) && $_ } @{$rr->{'Name Server'}};
- $rinfo->{domain}->{$domain}->{ns}=$po->create_local_object('hosts')->set(@ns) if @ns;
- return;
+ $rinfo->{domain}->{$domain}->{ns}=Net::DRI::Data::Hosts->new_set(@ns) if @ns;
 }
 
 ####################################################################################################
